(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[     29331,        714]
NotebookOptionsPosition[     25201,        628]
NotebookOutlinePosition[     27235,        679]
CellTagsIndexPosition[     26915,        667]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Semi-Classical Marcus Theory of Electron Transfer
The Bell-shaped Marcus curve in the Inverted Region.\
\>", "DemoTitle",
 CellChangeTimes->{{3.760886982965762*^9, 
  3.7608870383322372`*^9}},ExpressionUUID->"cd06441f-cef6-4998-9517-\
0190e010dbce"],

Cell["", "InitializationSection",ExpressionUUID->"f6b4d79d-c2d5-482c-9165-973517f44cd5"],

Cell[CellGroupData[{

Cell["", "ManipulateSection",ExpressionUUID->"bf87ee64-f745-44f3-97ec-2d670c2fe54f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"Ket", 
      StyleBox["=",
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["(",
        FontColor->GrayLevel[0]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"0.0000861733033", " ", 
               RowBox[{"(", "LambdaS", ")"}], " ", "T"}], ")"}], "0.5"]}], 
           ")"}]}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Pi]", 
           RowBox[{"3", "/", "2"}]], "*", 
          SuperscriptBox[
           RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
        SuperscriptBox["V", "2"], "*", 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"m", "=", "0"}], "n"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}]}]], 
                "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"LambdaI", "/", 
                   RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}], "^", 
                 "m"}]}], ")"}], "/", 
              RowBox[{"m", "!"}]}], ")"}], "*", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "x"}], "+", "LambdaS", "+", 
                  RowBox[{"m", "*", 
                   RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], 
                "2"], 
               RowBox[{"4", "*", "0.0000861733033", "*", 
                RowBox[{"(", "LambdaS", ")"}], " ", "T"}]]}]]}], ")"}]}], 
         ")"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "a", ",", "d"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10", "^", "c"}], ",", 
        RowBox[{"10", "^", "b"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<-Gibbs Free Energy change (eV)\>\"", ",", 
        "\"\<Rate of electron transfer(s^-1)\>\""}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"LambdaS", ",", "0.2", ",", " ", "\"\<Lambda solv (eV)\>\""}], 
      "}"}], ",", "0.00001", ",", "8", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"LambdaI", ",", "0.44", ",", " ", "\"\<Lambda Int (eV)\>\""}], 
      "}"}], ",", "0.01", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", "295", ",", " ", "\"\<T (K)\>\""}], "}"}], ",", "2", 
     ",", "500", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "vib", ",", "1500", ",", " ", 
       "\"\<vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], 
     ",", "4", ",", "10000", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "15", ",", " ", "\"\<n (no)\>\""}], "}"}], ",", "0", 
     ",", "100", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "V", ",", "6.2", ",", " ", 
       "\"\<V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], ",", 
     "0.5", ",", "1000", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", "10.5", ",", " ", "\"\<b (y-max)\>\""}], "}"}], ",", 
     "7", ",", "18", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "6", ",", " ", "\"\<bc (y-min)\>\""}], "}"}], ",", 
     "0", ",", "17", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "2.5", ",", " ", "\"\<a (x-min)\>\""}], "}"}], ",", 
     "0.0", ",", "8", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", 
       RowBox[{"-", "0.3"}], ",", " ", "\"\<d (x-max)\>\""}], "}"}], ",", 
     RowBox[{"-", "0.5"}], ",", "8", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"S", ",", 
       RowBox[{"LambdaI", "/", 
        RowBox[{"(", 
         RowBox[{"0.00012", "*", "vib"}], ")"}]}], ",", " ", 
       "\"\<S, Huang Rys\>\""}], "}"}], ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.7608898882805758`*^9, {3.8245530399198947`*^9, 3.824553054780345*^9}, {
   3.8245531907346125`*^9, 3.824553243022097*^9}, {3.8247428735259247`*^9, 
   3.824742874407188*^9}, {3.824742909927128*^9, 3.824742918023657*^9}, {
   3.824743323565845*^9, 3.82474338846152*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"02d9c860-55a9-4544-9bce-707aff8e1bcc"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2.5, $CellContext`b$$ = 
    10.5, $CellContext`c$$ = 
    6, $CellContext`d$$ = -0.3, $CellContext`LambdaI$$ = 
    0.44, $CellContext`LambdaS$$ = 0.2, $CellContext`n$$ = 
    15, $CellContext`S$$ = 
    8333.333333333334 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`T$$ = 295, $CellContext`V$$ = 6.2, $CellContext`vib$$ = 1500, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaS$$], 0.2, "Lambda solv (eV)"}, 0.00001, 8}, {{
      
       Hold[$CellContext`LambdaI$$], 0.44, "Lambda Int (eV)"}, 0.01, 2}, {{
       Hold[$CellContext`T$$], 295, "T (K)"}, 2, 500}, {{
       Hold[$CellContext`vib$$], 1500, 
       "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
       Hold[$CellContext`n$$], 15, "n (no)"}, 0, 100}, {{
       Hold[$CellContext`V$$], 6.2, 
       "V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 0.5, 1000}, {{
       Hold[$CellContext`b$$], 10.5, "b (y-max)"}, 7, 18}, {{
       Hold[$CellContext`c$$], 6, "bc (y-min)"}, 0, 17}, {{
       Hold[$CellContext`a$$], 2.5, "a (x-min)"}, 0., 8}, {{
       Hold[$CellContext`d$$], -0.3, "d (x-max)"}, -0.5, 8}, {{
       Hold[$CellContext`S$$], 
       8333.333333333334 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "S, Huang Rys"}}}, Typeset`size$$ = {700., {184., 189.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`LambdaS$27010$$ = 0, $CellContext`LambdaI$27011$$ = 
    0, $CellContext`T$27012$$ = 0, $CellContext`vib$27013$$ = 
    0, $CellContext`n$27014$$ = 0, $CellContext`V$27015$$ = 
    0, $CellContext`b$27016$$ = 0, $CellContext`c$27017$$ = 
    0, $CellContext`a$27018$$ = 0, $CellContext`d$27019$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 2.5, $CellContext`b$$ = 
        10.5, $CellContext`c$$ = 
        6, $CellContext`d$$ = -0.3, $CellContext`LambdaI$$ = 
        0.44, $CellContext`LambdaS$$ = 0.2, $CellContext`n$$ = 
        15, $CellContext`S$$ = 
        8333.333333333334 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`T$$ = 295, $CellContext`V$$ = 6.2, $CellContext`vib$$ = 1500}, 
      "ControllerVariables" :> {
        Hold[$CellContext`LambdaS$$, $CellContext`LambdaS$27010$$, 0], 
        Hold[$CellContext`LambdaI$$, $CellContext`LambdaI$27011$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$27012$$, 0], 
        Hold[$CellContext`vib$$, $CellContext`vib$27013$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$27014$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$27015$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$27016$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$27017$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$27018$$, 0], 
        Hold[$CellContext`d$$, $CellContext`d$27019$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      LogPlot[Ket = (((1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
             Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
         Sum[((E^(-($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
               0.000123985 $CellContext`vib$$))^$CellContext`m)/
            Factorial[$CellContext`m]) 
           E^(-((-$CellContext`x + $CellContext`LambdaS$$ + $CellContext`m (
                  0.000123985 $CellContext`vib$$))^2/(((4 
                0.0000861733033) $CellContext`LambdaS$$) $CellContext`T$$))), \
{$CellContext`m, 
            0, $CellContext`n$$}], {$CellContext`x, $CellContext`a$$, \
$CellContext`d$$}, PlotRange -> {10^$CellContext`c$$, 10^$CellContext`b$$}, 
        AxesLabel -> {
         "-Gibbs Free Energy change (eV)", "Rate of electron transfer(s^-1)"},
         ImageSize -> 700], 
      "Specifications" :> {{{$CellContext`LambdaS$$, 0.2, "Lambda solv (eV)"},
          0.00001, 8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaI$$, 0.44, "Lambda Int (eV)"}, 0.01,
          2, Appearance -> "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 2, 
         500, Appearance -> 
         "Labeled"}, {{$CellContext`vib$$, 1500, 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
         Appearance -> "Labeled"}, {{$CellContext`n$$, 15, "n (no)"}, 0, 100, 
         Appearance -> 
         "Labeled"}, {{$CellContext`V$$, 6.2, 
          "V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 0.5, 1000, 
         Appearance -> "Labeled"}, {{$CellContext`b$$, 10.5, "b (y-max)"}, 7, 
         18, Appearance -> "Labeled"}, {{$CellContext`c$$, 6, "bc (y-min)"}, 
         0, 17, Appearance -> 
         "Labeled"}, {{$CellContext`a$$, 2.5, "a (x-min)"}, 0., 8, Appearance -> 
         "Labeled"}, {{$CellContext`d$$, -0.3, "d (x-max)"}, -0.5, 8, 
         Appearance -> 
         "Labeled"}, {{$CellContext`S$$, 
          8333.333333333334 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "S, Huang Rys"}, Appearance -> "Labeled"}}, 
      "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{1075., {212., 218.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.7608898939207487`*^9, 3.8245529978201156`*^9, {3.824553060077433*^9, 
   3.8245530749979534`*^9}, 3.824742791367711*^9, {3.824742925290407*^9, 
   3.824742952122308*^9}, {3.82474323462399*^9, 3.8247432559025383`*^9}, {
   3.8247433391886377`*^9, 3.824743390572736*^9}, 3.824743464211669*^9},
 CellLabel->"Out[6]=",
 CellID->1912600514,ExpressionUUID->"7456c486-5a14-4a63-8304-33db58a2743e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateCaptionSection",ExpressionUUID->"fd663489-3f9b-4207-b2ef-268521a1cfc7"],

Cell["XXXX", "ManipulateCaption",ExpressionUUID->"302d07c6-02fe-4684-abc9-0d3700fd6edc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ThumbnailSection",ExpressionUUID->"ee8dee11-2f09-4ef6-a43f-53ca5aa2a910"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[1]], RectangleBox[{0, 0}], 
   InsetBox[
    StyleBox["\<\"Thumbnail Placeholder\"\>",
     StripOnInput->False,
     FontFamily->"Verdana",
     FontSize->14], {0.5, 0.6}], InsetBox[
    StyleBox["\<\"Replace this with your\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.45}], InsetBox[
    StyleBox["\<\"Manipulate at a particular setting.\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.39}], InsetBox[
    StyleBox["\<\"(Do not use a bitmap.)\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.315}]},
  ImageMargins->0.,
  ImageSize->220]], "Output",
 CellEditDuplicate->
  False,ExpressionUUID->"c6a896c9-2347-442b-a266-14bc166d0ed1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SnapshotsSection",ExpressionUUID->"5d2131fa-1858-433d-9fc7-45ce3c963648"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[1]], RectangleBox[{0, 0}], 
   InsetBox[
    StyleBox["\<\"Snapshot Placeholder\"\>",
     StripOnInput->False,
     FontFamily->"Verdana",
     FontSize->14], {0.5, 0.6}], InsetBox[
    StyleBox["\<\"Replace this with your\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.45}], InsetBox[
    StyleBox["\<\"Manipulate at a particular setting.\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.39}], InsetBox[
    StyleBox["\<\"(Do not use a bitmap.)\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.315}]},
  ImageMargins->0.,
  ImageSize->220]], "Output",
 CellEditDuplicate->
  False,ExpressionUUID->"e1f947cf-914e-4f18-8722-5a600df03d40"]
}, Open  ]],

Cell["", "DetailsSection",ExpressionUUID->"c36b1e03-9047-434c-8cd0-f943927aaaee"],

Cell[CellGroupData[{

Cell["", "ControlSuggestionsSection",ExpressionUUID->"274b42bf-5f4d-45c5-ad61-baabfe6f811a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"bdc94874-9112-4bc7-a8cf-70d6113d3095"]}],
  
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"5ceea481-7fa3-4c42-90ee-3ecb119a18c9"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "eddbaf2c-b1ee-46ed-bb13-5399374eb951"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" on Mac) and drag up and down to zoom.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"c825d213-971a-4bd0-bccd-b83d327c3201"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"63463c28-b423-4564-a422-c8ec2294db68"]}],
  
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"5405a9e7-3801-4a7f-ba0b-c28f417b6bdc"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "b3c2cb94-4b62-4523-a4d8-81bdf65ef88f"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"b5a5dd3d-691a-4c66-88c5-\
3076752e3753"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Slider Zoom",ExpressionUUID->"5e227277-20f6-4eb9-86e7-2d36d6205215"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" to make ever finer adjustments.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"cd527a51-b046-4eb1-b18a-3410745efb53"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "15f6d4d3-f798-46b3-8caf-ac29b7f62598"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"467ba4d2-738e-4d76-8d42-8914b41745d8"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ed8033a7-60cb-477e-bac7-f5ae20e36548"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"95a87a10-f466-457a-b910-b0f908d1f752"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "4da33221-b239-4270-9883-bee0ef23dd19"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"4e896c0f-2572-4aa7-935a-0faa6694b4a3"]
}, Open  ]],

Cell["", "SearchTermsSection",ExpressionUUID->"ff84138c-706a-4897-9a1f-097652198420"],

Cell["", "RelatedLinksSection",ExpressionUUID->"4d828e45-7343-47bc-a9e6-12a143caa27e"],

Cell[CellGroupData[{

Cell["", "AuthorSection",ExpressionUUID->"d745326b-62bb-426b-b9af-5882a77df039"],

Cell["Contributed by: XXXX", "Author",ExpressionUUID->"7fa71a4e-7543-4e3d-9e3e-11f052a3c493"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{Full, Full},
WindowMargins->{{96, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ResizeImages"->{
  Cell[18241, 443, 432, 11, 29, "ControlSuggestions",ExpressionUUID->"5ceea481-7fa3-4c42-90ee-3ecb119a18c9",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[18676, 456, 800, 19, 29, "ControlSuggestions",ExpressionUUID->"c825d213-971a-4bd0-bccd-b83d327c3201",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[19479, 477, 460, 14, 29, "ControlSuggestions",ExpressionUUID->"5405a9e7-3801-4a7f-ba0b-c28f417b6bdc",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[19942, 493, 761, 19, 29, "ControlSuggestions",ExpressionUUID->"b5a5dd3d-691a-4c66-88c5-3076752e3753",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[20706, 514, 961, 23, 29, "ControlSuggestions",ExpressionUUID->"cd527a51-b046-4eb1-b18a-3410745efb53",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[21670, 539, 491, 12, 29, "ControlSuggestions",ExpressionUUID->"467ba4d2-738e-4d76-8d42-8914b41745d8",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[22164, 553, 1586, 34, 29, "ControlSuggestions",ExpressionUUID->"95a87a10-f466-457a-b910-b0f908d1f752",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[23753, 589, 1030, 24, 29, "ControlSuggestions",ExpressionUUID->"4e896c0f-2572-4aa7-935a-0faa6694b4a3",
   CellTags->"BookmarkAnimation"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ResizeImages", 25581, 640},
 {"RotateAndZoomIn3D", 25745, 643},
 {"DragLocators", 25909, 646},
 {"CreateAndDeleteLocators", 26079, 649},
 {"SliderZoom", 26247, 652},
 {"GamepadControls", 26407, 655},
 {"AutomaticAnimation", 26575, 658},
 {"BookmarkAnimation", 26746, 661}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1510, 35, 259, 6, 108, "DemoTitle",ExpressionUUID->"cd06441f-cef6-4998-9517-0190e010dbce"],
Cell[1772, 43, 88, 0, 301, "InitializationSection",ExpressionUUID->"f6b4d79d-c2d5-482c-9165-973517f44cd5"],
Cell[CellGroupData[{
Cell[1885, 47, 84, 0, 205, "ManipulateSection",ExpressionUUID->"bf87ee64-f745-44f3-97ec-2d670c2fe54f"],
Cell[CellGroupData[{
Cell[1994, 51, 6484, 173, 19, "Input",ExpressionUUID->"02d9c860-55a9-4544-9bce-707aff8e1bcc",
 CellOpen->False],
Cell[8481, 226, 6468, 116, 442, "Output",ExpressionUUID->"7456c486-5a14-4a63-8304-33db58a2743e",
 CellID->1912600514]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14998, 348, 91, 0, 181, "ManipulateCaptionSection",ExpressionUUID->"fd663489-3f9b-4207-b2ef-268521a1cfc7"],
Cell[15092, 350, 88, 0, 23, "ManipulateCaption",ExpressionUUID->"302d07c6-02fe-4684-abc9-0d3700fd6edc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15217, 355, 83, 0, 179, "ThumbnailSection",ExpressionUUID->"ee8dee11-2f09-4ef6-a43f-53ca5aa2a910"],
Cell[15303, 357, 1300, 35, 230, "Output",ExpressionUUID->"c6a896c9-2347-442b-a266-14bc166d0ed1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16640, 397, 83, 0, 149, "SnapshotsSection",ExpressionUUID->"5d2131fa-1858-433d-9fc7-45ce3c963648"],
Cell[16726, 399, 1299, 35, 230, "Output",ExpressionUUID->"e1f947cf-914e-4f18-8722-5a600df03d40"]
}, Open  ]],
Cell[18040, 437, 81, 0, 359, "DetailsSection",ExpressionUUID->"c36b1e03-9047-434c-8cd0-f943927aaaee"],
Cell[CellGroupData[{
Cell[18146, 441, 92, 0, 119, "ControlSuggestionsSection",ExpressionUUID->"274b42bf-5f4d-45c5-ad61-baabfe6f811a"],
Cell[18241, 443, 432, 11, 29, "ControlSuggestions",ExpressionUUID->"5ceea481-7fa3-4c42-90ee-3ecb119a18c9",
 CellTags->"ResizeImages"],
Cell[18676, 456, 800, 19, 29, "ControlSuggestions",ExpressionUUID->"c825d213-971a-4bd0-bccd-b83d327c3201",
 CellTags->"RotateAndZoomIn3D"],
Cell[19479, 477, 460, 14, 29, "ControlSuggestions",ExpressionUUID->"5405a9e7-3801-4a7f-ba0b-c28f417b6bdc",
 CellTags->"DragLocators"],
Cell[19942, 493, 761, 19, 29, "ControlSuggestions",ExpressionUUID->"b5a5dd3d-691a-4c66-88c5-3076752e3753",
 CellTags->"CreateAndDeleteLocators"],
Cell[20706, 514, 961, 23, 29, "ControlSuggestions",ExpressionUUID->"cd527a51-b046-4eb1-b18a-3410745efb53",
 CellTags->"SliderZoom"],
Cell[21670, 539, 491, 12, 29, "ControlSuggestions",ExpressionUUID->"467ba4d2-738e-4d76-8d42-8914b41745d8",
 CellTags->"GamepadControls"],
Cell[22164, 553, 1586, 34, 29, "ControlSuggestions",ExpressionUUID->"95a87a10-f466-457a-b910-b0f908d1f752",
 CellTags->"AutomaticAnimation"],
Cell[23753, 589, 1030, 24, 29, "ControlSuggestions",ExpressionUUID->"4e896c0f-2572-4aa7-935a-0faa6694b4a3",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[24798, 616, 85, 0, 165, "SearchTermsSection",ExpressionUUID->"ff84138c-706a-4897-9a1f-097652198420"],
Cell[24886, 618, 86, 0, 137, "RelatedLinksSection",ExpressionUUID->"4d828e45-7343-47bc-a9e6-12a143caa27e"],
Cell[CellGroupData[{
Cell[24997, 622, 80, 0, 137, "AuthorSection",ExpressionUUID->"d745326b-62bb-426b-b9af-5882a77df039"],
Cell[25080, 624, 93, 0, 23, "Author",ExpressionUUID->"7fa71a4e-7543-4e3d-9e3e-11f052a3c493"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature dxpunV245PeN6AwsbUfmUK6R *)
