(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[    104612,       2477]
NotebookOptionsPosition[     85380,       2136]
NotebookOutlinePosition[     87430,       2187]
CellTagsIndexPosition[     87102,       2175]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Semi-Classical Marcus Theory of Electron Transfer
The Bell-shaped Marcus curve in the Inverted Region.\
\>", "DemoTitle",
 CellChangeTimes->{{3.760886982965762*^9, 
  3.7608870383322372`*^9}},ExpressionUUID->"cd06441f-cef6-4998-9517-\
0190e010dbce"],

Cell["", "InitializationSection",ExpressionUUID->"f6b4d79d-c2d5-482c-9165-973517f44cd5"],

Cell[CellGroupData[{

Cell["", "ManipulateSection",ExpressionUUID->"bf87ee64-f745-44f3-97ec-2d670c2fe54f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"Ket", 
      StyleBox["=",
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["(",
        FontColor->GrayLevel[0]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"0.0000861733033", " ", 
               RowBox[{"(", "LambdaS", ")"}], " ", "T"}], ")"}], "0.5"]}], 
           ")"}]}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Pi]", 
           RowBox[{"3", "/", "2"}]], "*", 
          SuperscriptBox[
           RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
        SuperscriptBox["V", "2"], "*", 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"m", "=", "0"}], "n"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}]}]], 
                "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"LambdaI", "/", 
                   RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}], "^", 
                 "m"}]}], ")"}], "/", 
              RowBox[{"m", "!"}]}], ")"}], "*", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "x"}], "+", "LambdaS", "+", 
                  RowBox[{"m", "*", 
                   RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], 
                "2"], 
               RowBox[{"4", "*", "0.0000861733033", "*", 
                RowBox[{"(", "LambdaS", ")"}], " ", "T"}]]}]]}], ")"}]}], 
         ")"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "a", ",", "d"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10", "^", "c"}], ",", 
        RowBox[{"10", "^", "b"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<-Gibbs Free Energy change (eV)\>\"", ",", 
        "\"\<Rate of electron transfer(s^-1)\>\""}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"LambdaS", ",", "0.2", ",", " ", "\"\<Lambda solv (eV)\>\""}], 
      "}"}], ",", "0.00001", ",", "8", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"LambdaI", ",", "0.44", ",", " ", "\"\<Lambda Int (eV)\>\""}], 
      "}"}], ",", "0.01", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", "295", ",", " ", "\"\<T (K)\>\""}], "}"}], ",", "2", 
     ",", "500", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "vib", ",", "1500", ",", " ", 
       "\"\<vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], 
     ",", "4", ",", "10000", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "50", ",", " ", "\"\<n (no)\>\""}], "}"}], ",", "0", 
     ",", "500", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "V", ",", "6.2", ",", " ", 
       "\"\<V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], ",", 
     "0.5", ",", "1000", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", "10.5", ",", " ", "\"\<b (y-max)\>\""}], "}"}], ",", 
     "7", ",", "18", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "6", ",", " ", "\"\<bc (y-min)\>\""}], "}"}], ",", 
     "0", ",", "17", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "2.5", ",", " ", "\"\<a (x-min)\>\""}], "}"}], ",", 
     "0.0", ",", "8", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", 
       RowBox[{"-", "0.3"}], ",", " ", "\"\<d (x-max)\>\""}], "}"}], ",", 
     RowBox[{"-", "0.5"}], ",", "8", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"HR", ",", 
       RowBox[{"LambdaI", "/", 
        RowBox[{"(", 
         RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ",", " ", 
       "\"\<S, Huang Rhys =\>\""}], "}"}], ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.7608898882805758`*^9, {3.8245530399198947`*^9, 3.824553054780345*^9}, {
   3.8245531907346125`*^9, 3.824553243022097*^9}, {3.8247428735259247`*^9, 
   3.824742874407188*^9}, {3.824742909927128*^9, 3.824742918023657*^9}, {
   3.824743323565845*^9, 3.82474338846152*^9}, 3.828248949536881*^9, {
   3.828277973225518*^9, 3.8282779746882133`*^9}, 3.8282781201062193`*^9, {
   3.828278225804035*^9, 3.828278226081213*^9}, {3.834323291600862*^9, 
   3.834323299368507*^9}},ExpressionUUID->"02d9c860-55a9-4544-9bce-\
707aff8e1bcc"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2.5, $CellContext`b$$ = 
    10.5, $CellContext`c$$ = 6, $CellContext`d$$ = -0.3, $CellContext`HR$$ = 
    8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`LambdaI$$ = 0.7379000000000004, $CellContext`LambdaS$$ = 
    0.00135, $CellContext`n$$ = 499, $CellContext`T$$ = 
    295, $CellContext`V$$ = 2.469999999997776, $CellContext`vib$$ = 740, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`LambdaS$$], 0.2, "Lambda solv (eV)"}, 0.00001, 8}, {{
      
       Hold[$CellContext`LambdaI$$], 0.44, "Lambda Int (eV)"}, 0.01, 2}, {{
       Hold[$CellContext`T$$], 295, "T (K)"}, 2, 500}, {{
       Hold[$CellContext`vib$$], 1500, 
       "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
       Hold[$CellContext`n$$], 15, "n (no)"}, 0, 100}, {{
       Hold[$CellContext`V$$], 6.2, 
       "V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 0.5, 1000}, {{
       Hold[$CellContext`b$$], 10.5, "b (y-max)"}, 7, 18}, {{
       Hold[$CellContext`c$$], 6, "bc (y-min)"}, 0, 17}, {{
       Hold[$CellContext`a$$], 2.5, "a (x-min)"}, 0., 8}, {{
       Hold[$CellContext`d$$], -0.3, "d (x-max)"}, -0.5, 8}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "S, Huang Rhys ="}}}, Typeset`size$$ = {700., {184., 189.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`LambdaS$9967$$ = 0, $CellContext`LambdaI$9968$$ = 
    0, $CellContext`T$9969$$ = 0, $CellContext`vib$9970$$ = 
    0, $CellContext`n$9971$$ = 0, $CellContext`V$9972$$ = 
    0, $CellContext`b$9973$$ = 0, $CellContext`c$9974$$ = 
    0, $CellContext`a$9975$$ = 0, $CellContext`d$9976$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 2.5, $CellContext`b$$ = 
        10.5, $CellContext`c$$ = 
        6, $CellContext`d$$ = -0.3, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`LambdaI$$ = 0.44, $CellContext`LambdaS$$ = 0.2, $CellContext`n$$ = 
        15, $CellContext`T$$ = 295, $CellContext`V$$ = 
        6.2, $CellContext`vib$$ = 1500}, "ControllerVariables" :> {
        Hold[$CellContext`LambdaS$$, $CellContext`LambdaS$9967$$, 0], 
        Hold[$CellContext`LambdaI$$, $CellContext`LambdaI$9968$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$9969$$, 0], 
        Hold[$CellContext`vib$$, $CellContext`vib$9970$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$9971$$, 0], 
        Hold[$CellContext`V$$, $CellContext`V$9972$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$9973$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$9974$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$9975$$, 0], 
        Hold[$CellContext`d$$, $CellContext`d$9976$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      LogPlot[Ket = (((1/(
            4.1356676623401640884816799999999999999999999`23.61654563206586*^-\
15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
             Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
         Sum[((E^(-($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
               0.000123985 $CellContext`vib$$))^$CellContext`m)/
            Factorial[$CellContext`m]) 
           E^(-((-$CellContext`x + $CellContext`LambdaS$$ + $CellContext`m (
                  0.000123985 $CellContext`vib$$))^2/(((4 
                0.0000861733033) $CellContext`LambdaS$$) $CellContext`T$$))), \
{$CellContext`m, 
            
            0, $CellContext`n$$}], {$CellContext`x, $CellContext`a$$, \
$CellContext`d$$}, PlotRange -> {10^$CellContext`c$$, 10^$CellContext`b$$}, 
        AxesLabel -> {
         "-Gibbs Free Energy change (eV)", "Rate of electron transfer(s^-1)"},
         ImageSize -> 700], 
      "Specifications" :> {{{$CellContext`LambdaS$$, 0.2, "Lambda solv (eV)"},
          0.00001, 8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaI$$, 0.44, "Lambda Int (eV)"}, 0.01,
          2, Appearance -> "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 2, 
         500, Appearance -> 
         "Labeled"}, {{$CellContext`vib$$, 1500, 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
         Appearance -> "Labeled"}, {{$CellContext`n$$, 15, "n (no)"}, 0, 100, 
         Appearance -> 
         "Labeled"}, {{$CellContext`V$$, 6.2, 
          "V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 0.5, 1000, 
         Appearance -> "Labeled"}, {{$CellContext`b$$, 10.5, "b (y-max)"}, 7, 
         18, Appearance -> "Labeled"}, {{$CellContext`c$$, 6, "bc (y-min)"}, 
         0, 17, Appearance -> 
         "Labeled"}, {{$CellContext`a$$, 2.5, "a (x-min)"}, 0., 8, Appearance -> 
         "Labeled"}, {{$CellContext`d$$, -0.3, "d (x-max)"}, -0.5, 8, 
         Appearance -> 
         "Labeled"}, {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "S, Huang Rhys ="}, Appearance -> "Labeled"}}, 
      "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{1078., {244., 249.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.7608898939207487`*^9, 3.8245529978201156`*^9, {3.824553060077433*^9, 
   3.8245530749979534`*^9}, 3.824742791367711*^9, {3.824742925290407*^9, 
   3.824742952122308*^9}, {3.82474323462399*^9, 3.8247432559025383`*^9}, {
   3.8247433391886377`*^9, 3.824743390572736*^9}, 3.824743464211669*^9, {
   3.8282779936570053`*^9, 3.828278004292885*^9}, 3.828278134624466*^9, {
   3.828278172075067*^9, 3.8282781748862762`*^9}, 3.828278229681203*^9, 
   3.828278260273159*^9, {3.834323336450017*^9, 3.834323348532234*^9}},
 CellLabel->"Out[3]=",
 CellID->539773618,ExpressionUUID->"f0a32427-e986-4ea1-80ba-b64303e05260"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,94,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343233700283117`*^9},
 CellLabel->"",
 CellID->184463189,ExpressionUUID->"a56af5a0-ee47-45aa-af9b-de5c29d11553"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,95,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343233700902357`*^9},
 CellLabel->"",
 CellID->1453914902,ExpressionUUID->"c387d3cd-45d7-4ccd-b429-2e4c8a8c1081"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,96,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323370145183*^9},
 CellLabel->"",
 CellID->1878822348,ExpressionUUID->"4af49475-0b61-42ba-b2d5-5b309bb21feb"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,97,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323370322776*^9},
 CellLabel->"",
 CellID->767657348,ExpressionUUID->"906d1619-7dde-4be8-a635-f6471dcc3a15"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,98,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323371298283*^9},
 CellLabel->"",
 CellID->2082780307,ExpressionUUID->"86afa4c8-5d5e-4557-b228-1bd9f1e7cdbc"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,99,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323371469295*^9},
 CellLabel->"",
 CellID->1305173649,ExpressionUUID->"b2145dbb-cf11-4b00-8218-889705050325"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,100,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323371539194*^9},
 CellLabel->"",
 CellID->1655548285,ExpressionUUID->"6ee1851d-3b89-45b9-a5e3-85cd00e8d44c"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,101,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323371603965*^9},
 CellLabel->"",
 CellID->2001895463,ExpressionUUID->"3169af9d-ad83-4136-be6b-f918d9cf6948"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,102,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323386439769*^9},
 CellLabel->"",
 CellID->2100290724,ExpressionUUID->"d78333a5-a011-484d-8ff9-553e5d2ae90a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,103,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343233865858727`*^9},
 CellLabel->"",
 CellID->1397492529,ExpressionUUID->"11462716-68a7-4fbe-ad29-3f8d16c6cf5c"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,104,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323386640562*^9},
 CellLabel->"",
 CellID->628287664,ExpressionUUID->"1e6134fe-1de3-4335-bb75-34bc6d401a1d"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,105,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323386689245*^9},
 CellLabel->"",
 CellID->453676549,ExpressionUUID->"75f4e2fb-bc38-4653-8625-3be96adc3a4c"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,106,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323387682804*^9},
 CellLabel->"",
 CellID->1374812193,ExpressionUUID->"4dba9562-217f-4b5d-a2ad-de43b2f1de07"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,107,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323387733294*^9},
 CellLabel->"",
 CellID->1691969678,ExpressionUUID->"4b988ce5-54e1-479a-9943-3d01c1a7b08c"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,108,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323387783577*^9},
 CellLabel->"",
 CellID->2103408219,ExpressionUUID->"5d16f9ce-e08b-4cd8-a3bc-2a016827e8b5"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,109,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432338801549*^9},
 CellLabel->"",
 CellID->106139819,ExpressionUUID->"6b038be7-74c7-4904-ad3d-4e058bc79b58"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,110,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323408565713*^9},
 CellLabel->"",
 CellID->373425116,ExpressionUUID->"9ff5d353-9808-40cc-9874-29bc8b73f50a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,111,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323408781921*^9},
 CellLabel->"",
 CellID->1208708078,ExpressionUUID->"cd9a4771-5406-4631-94a1-d58589080bb7"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,112,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323408843281*^9},
 CellLabel->"",
 CellID->1708849973,ExpressionUUID->"a75de684-6a60-4a13-b512-58ff3a19088a"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,113,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323408895212*^9},
 CellLabel->"",
 CellID->195201233,ExpressionUUID->"efec3376-ba61-4257-b645-3eecec571b1c"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,114,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432340982755*^9},
 CellLabel->"",
 CellID->1539594062,ExpressionUUID->"460ae80c-2d36-42bf-8d32-68a99462ae3b"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,115,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323409890514*^9},
 CellLabel->"",
 CellID->926937331,ExpressionUUID->"f0988b5a-6eaa-4eb1-b5d0-21afbcd8c8c7"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,116,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323410078426*^9},
 CellLabel->"",
 CellID->1189346779,ExpressionUUID->"db5f62d7-6a96-45fc-8dc0-b34fe4649db5"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,117,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323410146586*^9},
 CellLabel->"",
 CellID->573528377,ExpressionUUID->"cda611f0-e0d1-4626-af5c-ece7c569f1ca"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,118,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323421348236*^9},
 CellLabel->"",
 CellID->575636193,ExpressionUUID->"10c2b6b8-7745-4e1f-9847-6acdd5dba0de"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,119,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343234215834513`*^9},
 CellLabel->"",
 CellID->303666016,ExpressionUUID->"aafc2324-fa61-4713-abe5-4de7cb70ea9a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,120,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432342164178*^9},
 CellLabel->"",
 CellID->1293585640,ExpressionUUID->"476afd32-bb40-4b38-b316-fc30331ae85f"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,121,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323421698172*^9},
 CellLabel->"",
 CellID->169409252,ExpressionUUID->"df755496-945d-488b-af90-8f71296bd19d"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1797.1645432758173`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,122,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323423632061*^9},
 CellLabel->"",
 CellID->1845466089,ExpressionUUID->"06b07504-d7cd-42aa-a401-1a8ec950ac4d"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3489.3220030643574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,123,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323423682804*^9},
 CellLabel->"",
 CellID->642244202,ExpressionUUID->"18669a3a-a4b5-4777-83db-ebdce8824e1c"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"5737.757863986005`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,124,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323423864842*^9},
 CellLabel->"",
 CellID->945493192,ExpressionUUID->"9dc01c63-dcd5-4faf-8aab-10e5ac84c429"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,125,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323423912363*^9},
 CellLabel->"",
 CellID->1672573791,ExpressionUUID->"513706a9-f742-4ed8-904e-b4ffe5c304e4"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"7727.624264930126`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,126,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323446029831*^9},
 CellLabel->"",
 CellID->188985280,ExpressionUUID->"c81d9b92-ad9b-4f95-a988-984df66c4b9f"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"22529.512248006162`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,127,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343234462250137`*^9},
 CellLabel->"",
 CellID->147287047,ExpressionUUID->"432b3181-c533-4aa2-8891-833ff4195268"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"45066.9494338485`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,128,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323446286888*^9},
 CellLabel->"",
 CellID->1552237585,ExpressionUUID->"fd401873-7b71-46cb-92b5-3166a29db231"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,129,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343234463430157`*^9},
 CellLabel->"",
 CellID->825747339,ExpressionUUID->"4cb9dca4-af3a-49df-be1a-fee884fdcce1"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"7727.624264930126`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,130,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343234475383*^9},
 CellLabel->"",
 CellID->1296199659,ExpressionUUID->"24ff4b13-d437-4b9b-b1da-98e47f78ef04"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"22529.512248006162`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,131,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323447712503*^9},
 CellLabel->"",
 CellID->1153553645,ExpressionUUID->"2b3e489d-63c7-4667-b6f2-46901c1d6c94"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"45066.9494338485`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,132,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323447769725*^9},
 CellLabel->"",
 CellID->293746399,ExpressionUUID->"b690d433-761f-4aea-a96e-affcc17421c8"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,133,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323447823765*^9},
 CellLabel->"",
 CellID->2078307187,ExpressionUUID->"24db2c51-8b36-4e8e-89fb-c8c371b45528"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"791.101994464588`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,134,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323482473259*^9},
 CellLabel->"",
 CellID->1099182144,ExpressionUUID->"c347a01b-343b-43da-929a-ea8783ac8753"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2284.1893933233796`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,135,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432348253493*^9},
 CellLabel->"",
 CellID->1299962714,ExpressionUUID->"175a4948-764a-4190-b9f8-37303acfe7a0"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"4550.831712456654`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,136,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432348259548*^9},
 CellLabel->"",
 CellID->2122193267,ExpressionUUID->"70df329c-1e38-4a9a-a40d-5e5b68a231ba"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,137,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323482657166*^9},
 CellLabel->"",
 CellID->146345446,ExpressionUUID->"545a4dc4-01dc-4a25-a1e8-310cd79fd71a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"791.101994464588`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,138,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323483776846*^9},
 CellLabel->"",
 CellID->759135107,ExpressionUUID->"5df117e4-8bf5-4983-9a07-701c2fd930cd"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2284.1893933233796`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,139,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323483961549*^9},
 CellLabel->"",
 CellID->583396522,ExpressionUUID->"cf369728-8add-4d45-82ba-2ddc0bdfb46d"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"4550.831712456654`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,140,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323484017626*^9},
 CellLabel->"",
 CellID->1882496699,ExpressionUUID->"4b7487f7-22f5-4539-86a5-24a38deea699"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,141,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323484072714*^9},
 CellLabel->"",
 CellID->245448842,ExpressionUUID->"5b3689b3-ece2-4dff-afef-96eff66c44c2"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"817.3211885016243`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,142,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323488443145*^9},
 CellLabel->"",
 CellID->1027261713,ExpressionUUID->"b8f3e71e-b166-46a3-a228-64c17ccee995"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1211.595005025139`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,143,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323488623432*^9},
 CellLabel->"",
 CellID->1566572158,ExpressionUUID->"62b36024-8856-4f2c-aa2e-229d87fbaa6a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1683.2243135761025`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,144,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323488676263*^9},
 CellLabel->"",
 CellID->1228747286,ExpressionUUID->"528ce420-23c2-400f-b3d4-9d13bb36aa60"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,145,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323488726968*^9},
 CellLabel->"",
 CellID->1352886250,ExpressionUUID->"131f0900-f971-4f2b-b8c6-13e8395f0abe"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"817.3211885016243`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,146,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323489910198*^9},
 CellLabel->"",
 CellID->402349314,ExpressionUUID->"4fc2fc07-28b3-4700-a1bb-939694b1503e"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1211.595005025139`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,147,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343234900943604`*^9},
 CellLabel->"",
 CellID->2006399642,ExpressionUUID->"cadeb8cf-7c3e-4039-8d8d-d9d955de0632"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1683.2243135761025`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,148,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323490155035*^9},
 CellLabel->"",
 CellID->1770557900,ExpressionUUID->"7d963dec-5488-4e98-bbbb-4b4f1d850b2e"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,149,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323490204734*^9},
 CellLabel->"",
 CellID->85728821,ExpressionUUID->"d7d2cf1f-a07c-4c04-9339-2c8c40d143e5"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"832.6399127923328`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,150,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323501028768*^9},
 CellLabel->"",
 CellID->1036086511,ExpressionUUID->"ac3c5121-608b-45f8-b3c2-580a0bae78ab"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1023.8979972168719`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,151,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323501169142*^9},
 CellLabel->"",
 CellID->1708580501,ExpressionUUID->"d051d431-e416-4bdc-8c76-d543dd4b2900"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1234.911792899356`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,152,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235012144403`*^9},
 CellLabel->"",
 CellID->2108636270,ExpressionUUID->"64475ae7-0006-475f-871b-9e4d28a4ffd9"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,153,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235012605762`*^9},
 CellLabel->"",
 CellID->2074647096,ExpressionUUID->"bef7641f-fc20-4927-ac96-24c37280c821"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"832.6399127923328`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,154,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235025972853`*^9},
 CellLabel->"",
 CellID->2049249780,ExpressionUUID->"bdd543a7-1c90-47d7-ae48-094481414fc6"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1023.8979972168719`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,155,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323502743967*^9},
 CellLabel->"",
 CellID->398321874,ExpressionUUID->"f9331a48-ea6b-4d3a-b774-2373aac7a9d5"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1234.911792899356`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,156,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323502795395*^9},
 CellLabel->"",
 CellID->889208619,ExpressionUUID->"abdaa819-863b-4267-b6dc-7351f64dcffe"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,157,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323502843322*^9},
 CellLabel->"",
 CellID->590560060,ExpressionUUID->"c5b527d7-e7c8-4ede-9f99-c4d160cb882a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3265.4970491128574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,158,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235152977*^9},
 CellLabel->"",
 CellID->1486412803,ExpressionUUID->"5c025b57-5086-4f61-ad6a-2d36ef23533f"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"7845.279739401666`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,159,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323515460998*^9},
 CellLabel->"",
 CellID->462714470,ExpressionUUID->"0e38f96b-1184-41dd-b4aa-e51530044c09"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"14400.633555484994`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,160,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235155099373`*^9},
 CellLabel->"",
 CellID->803811503,ExpressionUUID->"48aed172-f8cc-4d63-b8ef-ad306f9a2342"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,161,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323515556788*^9},
 CellLabel->"",
 CellID->1987791291,ExpressionUUID->"80d67a2a-4556-42f8-be21-f5daf0b70946"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"3265.4970491128574`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,162,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323516850986*^9},
 CellLabel->"",
 CellID->405131458,ExpressionUUID->"6c11db96-0c5d-4aa1-9f12-9afee64a199e"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"7845.279739401666`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,163,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323516896583*^9},
 CellLabel->"",
 CellID->1521253616,ExpressionUUID->"bb1e202c-70aa-4358-922d-3224145835da"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"14400.633555484994`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,164,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323516949582*^9},
 CellLabel->"",
 CellID->1916706577,ExpressionUUID->"d54ce087-8302-4d13-98af-dae2c2e097b3"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,165,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323517100915*^9},
 CellLabel->"",
 CellID->1832734639,ExpressionUUID->"b210be33-f80d-42c5-baad-796830b46ae5"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"780.2733541492834`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,166,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323523579686*^9},
 CellLabel->"",
 CellID->1716904035,ExpressionUUID->"3b7672d1-a974-4afd-8e69-04e728efd7c0"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1076.5316155979624`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,167,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432352374846*^9},
 CellLabel->"",
 CellID->268351506,ExpressionUUID->"1fdd6535-bd52-4aa4-af96-3bfc06882d2a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1420.3634074467132`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,168,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235237977343`*^9},
 CellLabel->"",
 CellID->468102642,ExpressionUUID->"b03c118c-ab25-4ea5-8ef1-cde4d83fdc81"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,169,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323523846026*^9},
 CellLabel->"",
 CellID->1168505133,ExpressionUUID->"abb85d54-6830-4bf7-b9ab-322228308de9"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"780.2733541492834`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,170,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323524658246*^9},
 CellLabel->"",
 CellID->327818516,ExpressionUUID->"832cd7fa-7cc5-4a58-86a4-66cd595e38c3"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1076.5316155979624`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,171,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323524815672*^9},
 CellLabel->"",
 CellID->1350243857,ExpressionUUID->"2e70331c-d5b3-4518-b31d-25c03b6c050f"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1420.3634074467132`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,172,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323524865118*^9},
 CellLabel->"",
 CellID->1088806750,ExpressionUUID->"26c3509b-1473-48ed-8aaf-f855fa256475"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,173,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323524922517*^9},
 CellLabel->"",
 CellID->866891163,ExpressionUUID->"0c21317e-3326-4c9c-9eb2-204e26439781"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,174,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323530793293*^9},
 CellLabel->"",
 CellID->42923341,ExpressionUUID->"c5a53b8b-a742-46f6-a2d7-6deb2b18a417"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,175,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235308421288`*^9},
 CellLabel->"",
 CellID->2005570442,ExpressionUUID->"0a597030-8d90-4197-b2a6-d0facb597471"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,176,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323530996977*^9},
 CellLabel->"",
 CellID->719095382,ExpressionUUID->"7dc90549-1595-4f3e-a96f-94eac9ef7c6b"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,177,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323531039274*^9},
 CellLabel->"",
 CellID->1945603605,ExpressionUUID->"8c5a27c5-8f90-41f5-908a-e80607111410"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,178,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323532874745*^9},
 CellLabel->"",
 CellID->26296366,ExpressionUUID->"ffd31587-85fb-43f0-8f02-63a9349535b9"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,179,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323532926092*^9},
 CellLabel->"",
 CellID->1728875727,ExpressionUUID->"24b20295-8c3c-4e53-beef-6f43d506b86e"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,180,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323533080318*^9},
 CellLabel->"",
 CellID->1760599779,ExpressionUUID->"5df3d9f8-7647-4ebd-9806-8bc225ed0f4a"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,181,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235331379757`*^9},
 CellLabel->"",
 CellID->223313640,ExpressionUUID->"7cde7118-c45f-4ecc-aa25-dbfb6c7ca5ae"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,182,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323559014027*^9},
 CellLabel->"",
 CellID->958434110,ExpressionUUID->"a95f7b29-a512-4e37-8976-00d64d4238df"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,183,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323559196611*^9},
 CellLabel->"",
 CellID->127250623,ExpressionUUID->"e4a3c4c0-e7ad-41f2-b8be-7b050b1e7f0a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,184,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323559250514*^9},
 CellLabel->"",
 CellID->1954991996,ExpressionUUID->"16e83bbf-2d21-4468-b660-8928bb590ac4"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,185,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323559308208*^9},
 CellLabel->"",
 CellID->1050677672,ExpressionUUID->"ba8a993f-4d22-41a7-be0e-ec1832801aaf"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,186,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323559948524*^9},
 CellLabel->"",
 CellID->2129087670,ExpressionUUID->"6b3e79c3-2462-49f3-a816-d88044c7a544"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,187,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432356013229*^9},
 CellLabel->"",
 CellID->56459729,ExpressionUUID->"0b18fa73-b2f3-4bb5-9315-fbefc0e17e9d"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,188,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323560187747*^9},
 CellLabel->"",
 CellID->1878376976,ExpressionUUID->"97aabbd0-d9ad-4d50-8486-22107796d236"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,189,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323560239951*^9},
 CellLabel->"",
 CellID->1872224732,ExpressionUUID->"b0e0de06-f757-4e95-aa36-213c40edc071"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,190,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323566874723*^9},
 CellLabel->"",
 CellID->606404054,ExpressionUUID->"4a4cd1d8-91eb-41e2-82bd-2a3006a9ba14"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,191,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235669251328`*^9},
 CellLabel->"",
 CellID->2023030563,ExpressionUUID->"a0d45052-65bd-45cf-b5be-774f64130c9a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,192,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323567071207*^9},
 CellLabel->"",
 CellID->2113573037,ExpressionUUID->"8f3fac5d-6488-46d1-8229-14e70d07e41f"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,193,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235671204557`*^9},
 CellLabel->"",
 CellID->1295027832,ExpressionUUID->"d9df0f8b-668a-4843-a6b0-fefe0dc9b224"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,194,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235679825706`*^9},
 CellLabel->"",
 CellID->786010079,ExpressionUUID->"97af09fa-77ea-430d-bb95-b4f51e3d1bf0"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,195,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323568137075*^9},
 CellLabel->"",
 CellID->1299485056,ExpressionUUID->"ec8e02a6-0683-4a7b-a514-9022fe63c43b"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,196,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323568184331*^9},
 CellLabel->"",
 CellID->536646202,ExpressionUUID->"7ce92f86-b714-45fe-a446-271c890421e0"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,197,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323568237029*^9},
 CellLabel->"",
 CellID->2128883261,ExpressionUUID->"e22bb000-2c92-4c59-829d-5f93c6d5a955"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,198,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323575071307*^9},
 CellLabel->"",
 CellID->1580505039,ExpressionUUID->"1a961b1b-73b9-46d0-a35a-b7f0dd757599"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,199,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235752388887`*^9},
 CellLabel->"",
 CellID->1322960730,ExpressionUUID->"5719a4b4-bbf6-45e1-9d28-b22dfe6fa51e"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,200,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323575281584*^9},
 CellLabel->"",
 CellID->2102791719,ExpressionUUID->"b294267f-a9d7-4c57-a336-1fcc2dd5aede"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,201,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323575324785*^9},
 CellLabel->"",
 CellID->482042554,ExpressionUUID->"2a99e7ba-27a8-4330-8ac4-67da3408181b"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,202,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323577259481*^9},
 CellLabel->"",
 CellID->1380888594,ExpressionUUID->"2a72a437-dc0a-45cd-8312-8dbadaf0c21b"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,203,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.83432357744672*^9},
 CellLabel->"",
 CellID->738826229,ExpressionUUID->"c3df5abd-d007-42f3-96de-7c5d5a30cd2a"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,204,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323577500731*^9},
 CellLabel->"",
 CellID->701983849,ExpressionUUID->"06b75c04-9977-4cec-b422-9f5b4212a672"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,205,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323577562636*^9},
 CellLabel->"",
 CellID->2114877172,ExpressionUUID->"c5afd020-c210-40d5-8889-8de97403db61"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,206,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235840885*^9},
 CellLabel->"",
 CellID->1642766536,ExpressionUUID->"2f8c8928-f5d0-4548-b8a1-6673774d7601"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,207,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323584247136*^9},
 CellLabel->"",
 CellID->1927404720,ExpressionUUID->"de0e5280-08be-4259-9be6-74bc21e8bdd4"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,208,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323584288443*^9},
 CellLabel->"",
 CellID->1247797692,ExpressionUUID->"49d2730e-dd68-4a3f-882b-6bb2b4e279f0"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,209,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235843430967`*^9},
 CellLabel->"",
 CellID->1557996489,ExpressionUUID->"6f49a47a-b9e9-4577-84b2-b42f98074295"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,210,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323598729556*^9},
 CellLabel->"",
 CellID->978882752,ExpressionUUID->"1e42b12c-ec42-4b27-85ac-616f9ad52e14"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,211,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323598780039*^9},
 CellLabel->"",
 CellID->210193197,ExpressionUUID->"a21668b5-767e-455c-ad44-0e9c884a89ac"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,212,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323598830351*^9},
 CellLabel->"",
 CellID->106462664,ExpressionUUID->"eb3819b3-0156-4e21-b76a-f7654f64a160"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,213,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343235988806953`*^9},
 CellLabel->"",
 CellID->464115897,ExpressionUUID->"0e7caf23-879c-4d67-a166-b893bb8c425b"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,214,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343236399272327`*^9},
 CellLabel->"",
 CellID->363035951,ExpressionUUID->"4adaa144-f0f9-4e89-bcca-186685f09e27"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,215,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343236401208*^9},
 CellLabel->"",
 CellID->544187330,ExpressionUUID->"b51d9ea7-1d71-4f8b-bbd7-a453adf34e11"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,216,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323640179454*^9},
 CellLabel->"",
 CellID->23602737,ExpressionUUID->"ba49ff56-d37a-4322-8a6a-8681acf387fe"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,217,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323640234006*^9},
 CellLabel->"",
 CellID->1554209711,ExpressionUUID->"de8cef34-a9e5-4ae6-8178-64b775d783c9"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1125.3529199769214`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,218,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323654633938*^9},
 CellLabel->"",
 CellID->1759014316,ExpressionUUID->"11c1dac1-53a2-47ed-8b4c-bb4109ca13cc"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"1712.0634811484078`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,219,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323654785857*^9},
 CellLabel->"",
 CellID->1493724410,ExpressionUUID->"eee0e053-4bad-4b6b-8836-ff4b8b6d6f27"],

Cell[BoxData[
 TemplateBox[{
  "General","munfl",
   "\"\\!\\(\\*RowBox[{\\\"Exp\\\", \\\"[\\\", RowBox[{\\\"-\\\", \
\\\"2421.4171681330295`\\\"}], \\\"]\\\"}]\\) is too small to represent as a \
normalized machine number; precision may be lost.\"",2,1,220,
   25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8343236548334303`*^9},
 CellLabel->"",
 CellID->942325440,ExpressionUUID->"459d6ae8-d57e-478e-993e-d31313b697bb"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"General\\\", \
\\\"::\\\", \\\"munfl\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,1,221,25725273870447626800,"LinkSnooper"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.834323654879795*^9},
 CellLabel->"",
 CellID->2119257102,ExpressionUUID->"6d81a68f-0e0c-4a42-8c3d-0853ce40af32"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ManipulateCaptionSection",ExpressionUUID->"fd663489-3f9b-4207-b2ef-268521a1cfc7"],

Cell["XXXX", "ManipulateCaption",ExpressionUUID->"302d07c6-02fe-4684-abc9-0d3700fd6edc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "ThumbnailSection",ExpressionUUID->"ee8dee11-2f09-4ef6-a43f-53ca5aa2a910"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[1]], RectangleBox[{0, 0}], 
   InsetBox[
    StyleBox["\<\"Thumbnail Placeholder\"\>",
     StripOnInput->False,
     FontFamily->"Verdana",
     FontSize->14], {0.5, 0.6}], InsetBox[
    StyleBox["\<\"Replace this with your\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.45}], InsetBox[
    StyleBox["\<\"Manipulate at a particular setting.\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.39}], InsetBox[
    StyleBox["\<\"(Do not use a bitmap.)\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.315}]},
  ImageMargins->0.,
  ImageSize->220]], "Output",
 CellEditDuplicate->
  False,ExpressionUUID->"c6a896c9-2347-442b-a266-14bc166d0ed1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SnapshotsSection",ExpressionUUID->"5d2131fa-1858-433d-9fc7-45ce3c963648"],

Cell[BoxData[
 GraphicsBox[
  {EdgeForm[GrayLevel[0]], FaceForm[GrayLevel[1]], RectangleBox[{0, 0}], 
   InsetBox[
    StyleBox["\<\"Snapshot Placeholder\"\>",
     StripOnInput->False,
     FontFamily->"Verdana",
     FontSize->14], {0.5, 0.6}], InsetBox[
    StyleBox["\<\"Replace this with your\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.45}], InsetBox[
    StyleBox["\<\"Manipulate at a particular setting.\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.39}], InsetBox[
    StyleBox["\<\"(Do not use a bitmap.)\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0.5],
     GraphicsColor->GrayLevel[0.5],
     FontFamily->"Verdana",
     FontSize->10,
     FontColor->GrayLevel[0.5],
     $CellContext`BackFaceColor -> GrayLevel[0.5]], {0.5, 0.315}]},
  ImageMargins->0.,
  ImageSize->220]], "Output",
 CellEditDuplicate->
  False,ExpressionUUID->"e1f947cf-914e-4f18-8722-5a600df03d40"]
}, Open  ]],

Cell["", "DetailsSection",ExpressionUUID->"c36b1e03-9047-434c-8cd0-f943927aaaee"],

Cell[CellGroupData[{

Cell["", "ControlSuggestionsSection",ExpressionUUID->"274b42bf-5f4d-45c5-ad61-baabfe6f811a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"bdc94874-9112-4bc7-a8cf-70d6113d3095"]}],
  
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"5ceea481-7fa3-4c42-90ee-3ecb119a18c9"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "eddbaf2c-b1ee-46ed-bb13-5399374eb951"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" on Mac) and drag up and down to zoom.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"c825d213-971a-4bd0-bccd-b83d327c3201"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"63463c28-b423-4564-a422-c8ec2294db68"]}],
  
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"5405a9e7-3801-4a7f-ba0b-c28f417b6bdc"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "b3c2cb94-4b62-4523-a4d8-81bdf65ef88f"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"b5a5dd3d-691a-4c66-88c5-\
3076752e3753"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Slider Zoom",ExpressionUUID->"5e227277-20f6-4eb9-86e7-2d36d6205215"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" to make ever finer adjustments.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"cd527a51-b046-4eb1-b18a-3410745efb53"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "15f6d4d3-f798-46b3-8caf-ac29b7f62598"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\"",
  TooltipDelay->0.35]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"467ba4d2-738e-4d76-8d42-8914b41745d8"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ed8033a7-60cb-477e-bac7-f5ae20e36548"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"95a87a10-f466-457a-b910-b0f908d1f752"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "4da33221-b239-4270-9883-bee0ef23dd19"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}],
  TooltipDelay->0.35]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"4e896c0f-2572-4aa7-935a-0faa6694b4a3"]
}, Open  ]],

Cell["", "SearchTermsSection",ExpressionUUID->"ff84138c-706a-4897-9a1f-097652198420"],

Cell["", "RelatedLinksSection",ExpressionUUID->"4d828e45-7343-47bc-a9e6-12a143caa27e"],

Cell[CellGroupData[{

Cell["", "AuthorSection",ExpressionUUID->"d745326b-62bb-426b-b9af-5882a77df039"],

Cell["Contributed by: XXXX", "Author",ExpressionUUID->"7fa71a4e-7543-4e3d-9e3e-11f052a3c493"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{Full, Full},
WindowMargins->{{96, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ResizeImages"->{
  Cell[78420, 1951, 432, 11, 29, "ControlSuggestions",ExpressionUUID->"5ceea481-7fa3-4c42-90ee-3ecb119a18c9",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[78855, 1964, 800, 19, 29, "ControlSuggestions",ExpressionUUID->"c825d213-971a-4bd0-bccd-b83d327c3201",
   CellTags->"RotateAndZoomIn3D"]},
 "DragLocators"->{
  Cell[79658, 1985, 460, 14, 29, "ControlSuggestions",ExpressionUUID->"5405a9e7-3801-4a7f-ba0b-c28f417b6bdc",
   CellTags->"DragLocators"]},
 "CreateAndDeleteLocators"->{
  Cell[80121, 2001, 761, 19, 29, "ControlSuggestions",ExpressionUUID->"b5a5dd3d-691a-4c66-88c5-3076752e3753",
   CellTags->"CreateAndDeleteLocators"]},
 "SliderZoom"->{
  Cell[80885, 2022, 961, 23, 29, "ControlSuggestions",ExpressionUUID->"cd527a51-b046-4eb1-b18a-3410745efb53",
   CellTags->"SliderZoom"]},
 "GamepadControls"->{
  Cell[81849, 2047, 491, 12, 29, "ControlSuggestions",ExpressionUUID->"467ba4d2-738e-4d76-8d42-8914b41745d8",
   CellTags->"GamepadControls"]},
 "AutomaticAnimation"->{
  Cell[82343, 2061, 1586, 34, 29, "ControlSuggestions",ExpressionUUID->"95a87a10-f466-457a-b910-b0f908d1f752",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[83932, 2097, 1030, 24, 29, "ControlSuggestions",ExpressionUUID->"4e896c0f-2572-4aa7-935a-0faa6694b4a3",
   CellTags->"BookmarkAnimation"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ResizeImages", 85760, 2148},
 {"RotateAndZoomIn3D", 85925, 2151},
 {"DragLocators", 86090, 2154},
 {"CreateAndDeleteLocators", 86261, 2157},
 {"SliderZoom", 86430, 2160},
 {"GamepadControls", 86591, 2163},
 {"AutomaticAnimation", 86760, 2166},
 {"BookmarkAnimation", 86932, 2169}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1510, 35, 259, 6, 108, "DemoTitle",ExpressionUUID->"cd06441f-cef6-4998-9517-0190e010dbce"],
Cell[1772, 43, 88, 0, 301, "InitializationSection",ExpressionUUID->"f6b4d79d-c2d5-482c-9165-973517f44cd5"],
Cell[CellGroupData[{
Cell[1885, 47, 84, 0, 205, "ManipulateSection",ExpressionUUID->"bf87ee64-f745-44f3-97ec-2d670c2fe54f"],
Cell[CellGroupData[{
Cell[1994, 51, 6651, 175, 475, "Input",ExpressionUUID->"02d9c860-55a9-4544-9bce-707aff8e1bcc"],
Cell[8648, 228, 6710, 118, 505, "Output",ExpressionUUID->"f0a32427-e986-4ea1-80ba-b64303e05260",
 CellID->539773618],
Cell[15361, 348, 473, 10, 22, "Message",ExpressionUUID->"a56af5a0-ee47-45aa-af9b-de5c29d11553",
 CellID->184463189],
Cell[15837, 360, 474, 10, 22, "Message",ExpressionUUID->"c387d3cd-45d7-4ccd-b429-2e4c8a8c1081",
 CellID->1453914902],
Cell[16314, 372, 471, 10, 22, "Message",ExpressionUUID->"4af49475-0b61-42ba-b2d5-5b309bb21feb",
 CellID->1878822348],
Cell[16788, 384, 437, 9, 22, "Message",ExpressionUUID->"906d1619-7dde-4be8-a635-f6471dcc3a15",
 CellID->767657348],
Cell[17228, 395, 472, 10, 22, "Message",ExpressionUUID->"86afa4c8-5d5e-4557-b228-1bd9f1e7cdbc",
 CellID->2082780307],
Cell[17703, 407, 472, 10, 22, "Message",ExpressionUUID->"b2145dbb-cf11-4b00-8218-889705050325",
 CellID->1305173649],
Cell[18178, 419, 472, 10, 22, "Message",ExpressionUUID->"6ee1851d-3b89-45b9-a5e3-85cd00e8d44c",
 CellID->1655548285],
Cell[18653, 431, 439, 9, 22, "Message",ExpressionUUID->"3169af9d-ad83-4136-be6b-f918d9cf6948",
 CellID->2001895463],
Cell[19095, 442, 473, 10, 22, "Message",ExpressionUUID->"d78333a5-a011-484d-8ff9-553e5d2ae90a",
 CellID->2100290724],
Cell[19571, 454, 475, 10, 22, "Message",ExpressionUUID->"11462716-68a7-4fbe-ad29-3f8d16c6cf5c",
 CellID->1397492529],
Cell[20049, 466, 471, 10, 22, "Message",ExpressionUUID->"1e6134fe-1de3-4335-bb75-34bc6d401a1d",
 CellID->628287664],
Cell[20523, 478, 438, 9, 22, "Message",ExpressionUUID->"75f4e2fb-bc38-4653-8625-3be96adc3a4c",
 CellID->453676549],
Cell[20964, 489, 473, 10, 22, "Message",ExpressionUUID->"4dba9562-217f-4b5d-a2ad-de43b2f1de07",
 CellID->1374812193],
Cell[21440, 501, 473, 10, 22, "Message",ExpressionUUID->"4b988ce5-54e1-479a-9943-3d01c1a7b08c",
 CellID->1691969678],
Cell[21916, 513, 472, 10, 22, "Message",ExpressionUUID->"5d16f9ce-e08b-4cd8-a3bc-2a016827e8b5",
 CellID->2103408219],
Cell[22391, 525, 437, 9, 22, "Message",ExpressionUUID->"6b038be7-74c7-4904-ad3d-4e058bc79b58",
 CellID->106139819],
Cell[22831, 536, 472, 10, 22, "Message",ExpressionUUID->"9ff5d353-9808-40cc-9874-29bc8b73f50a",
 CellID->373425116],
Cell[23306, 548, 473, 10, 22, "Message",ExpressionUUID->"cd9a4771-5406-4631-94a1-d58589080bb7",
 CellID->1208708078],
Cell[23782, 560, 472, 10, 22, "Message",ExpressionUUID->"a75de684-6a60-4a13-b512-58ff3a19088a",
 CellID->1708849973],
Cell[24257, 572, 438, 9, 22, "Message",ExpressionUUID->"efec3376-ba61-4257-b645-3eecec571b1c",
 CellID->195201233],
Cell[24698, 583, 472, 10, 22, "Message",ExpressionUUID->"460ae80c-2d36-42bf-8d32-68a99462ae3b",
 CellID->1539594062],
Cell[25173, 595, 472, 10, 22, "Message",ExpressionUUID->"f0988b5a-6eaa-4eb1-b5d0-21afbcd8c8c7",
 CellID->926937331],
Cell[25648, 607, 472, 10, 22, "Message",ExpressionUUID->"db5f62d7-6a96-45fc-8dc0-b34fe4649db5",
 CellID->1189346779],
Cell[26123, 619, 438, 9, 22, "Message",ExpressionUUID->"cda611f0-e0d1-4626-af5c-ece7c569f1ca",
 CellID->573528377],
Cell[26564, 630, 472, 10, 22, "Message",ExpressionUUID->"10c2b6b8-7745-4e1f-9847-6acdd5dba0de",
 CellID->575636193],
Cell[27039, 642, 474, 10, 22, "Message",ExpressionUUID->"aafc2324-fa61-4713-abe5-4de7cb70ea9a",
 CellID->303666016],
Cell[27516, 654, 471, 10, 22, "Message",ExpressionUUID->"476afd32-bb40-4b38-b316-fc30331ae85f",
 CellID->1293585640],
Cell[27990, 666, 438, 9, 22, "Message",ExpressionUUID->"df755496-945d-488b-af90-8f71296bd19d",
 CellID->169409252],
Cell[28431, 677, 473, 10, 22, "Message",ExpressionUUID->"06b07504-d7cd-42aa-a401-1a8ec950ac4d",
 CellID->1845466089],
Cell[28907, 689, 472, 10, 22, "Message",ExpressionUUID->"18669a3a-a4b5-4777-83db-ebdce8824e1c",
 CellID->642244202],
Cell[29382, 701, 471, 10, 22, "Message",ExpressionUUID->"9dc01c63-dcd5-4faf-8aab-10e5ac84c429",
 CellID->945493192],
Cell[29856, 713, 439, 9, 22, "Message",ExpressionUUID->"513706a9-f742-4ed8-904e-b4ffe5c304e4",
 CellID->1672573791],
Cell[30298, 724, 471, 10, 22, "Message",ExpressionUUID->"c81d9b92-ad9b-4f95-a988-984df66c4b9f",
 CellID->188985280],
Cell[30772, 736, 474, 10, 22, "Message",ExpressionUUID->"432b3181-c533-4aa2-8891-833ff4195268",
 CellID->147287047],
Cell[31249, 748, 471, 10, 22, "Message",ExpressionUUID->"fd401873-7b71-46cb-92b5-3166a29db231",
 CellID->1552237585],
Cell[31723, 760, 440, 9, 22, "Message",ExpressionUUID->"4cb9dca4-af3a-49df-be1a-fee884fdcce1",
 CellID->825747339],
Cell[32166, 771, 470, 10, 22, "Message",ExpressionUUID->"24ff4b13-d437-4b9b-b1da-98e47f78ef04",
 CellID->1296199659],
Cell[32639, 783, 473, 10, 22, "Message",ExpressionUUID->"2b3e489d-63c7-4667-b6f2-46901c1d6c94",
 CellID->1153553645],
Cell[33115, 795, 470, 10, 22, "Message",ExpressionUUID->"b690d433-761f-4aea-a96e-affcc17421c8",
 CellID->293746399],
Cell[33588, 807, 439, 9, 22, "Message",ExpressionUUID->"24db2c51-8b36-4e8e-89fb-c8c371b45528",
 CellID->2078307187],
Cell[34030, 818, 471, 10, 22, "Message",ExpressionUUID->"c347a01b-343b-43da-929a-ea8783ac8753",
 CellID->1099182144],
Cell[34504, 830, 472, 10, 22, "Message",ExpressionUUID->"175a4948-764a-4190-b9f8-37303acfe7a0",
 CellID->1299962714],
Cell[34979, 842, 471, 10, 22, "Message",ExpressionUUID->"70df329c-1e38-4a9a-a40d-5e5b68a231ba",
 CellID->2122193267],
Cell[35453, 854, 438, 9, 22, "Message",ExpressionUUID->"545a4dc4-01dc-4a25-a1e8-310cd79fd71a",
 CellID->146345446],
Cell[35894, 865, 470, 10, 22, "Message",ExpressionUUID->"5df117e4-8bf5-4983-9a07-701c2fd930cd",
 CellID->759135107],
Cell[36367, 877, 472, 10, 22, "Message",ExpressionUUID->"cf369728-8add-4d45-82ba-2ddc0bdfb46d",
 CellID->583396522],
Cell[36842, 889, 472, 10, 22, "Message",ExpressionUUID->"4b7487f7-22f5-4539-86a5-24a38deea699",
 CellID->1882496699],
Cell[37317, 901, 438, 9, 22, "Message",ExpressionUUID->"5b3689b3-ece2-4dff-afef-96eff66c44c2",
 CellID->245448842],
Cell[37758, 912, 472, 10, 22, "Message",ExpressionUUID->"b8f3e71e-b166-46a3-a228-64c17ccee995",
 CellID->1027261713],
Cell[38233, 924, 472, 10, 22, "Message",ExpressionUUID->"62b36024-8856-4f2c-aa2e-229d87fbaa6a",
 CellID->1566572158],
Cell[38708, 936, 473, 10, 22, "Message",ExpressionUUID->"528ce420-23c2-400f-b3d4-9d13bb36aa60",
 CellID->1228747286],
Cell[39184, 948, 439, 9, 22, "Message",ExpressionUUID->"131f0900-f971-4f2b-b8c6-13e8395f0abe",
 CellID->1352886250],
Cell[39626, 959, 471, 10, 22, "Message",ExpressionUUID->"4fc2fc07-28b3-4700-a1bb-939694b1503e",
 CellID->402349314],
Cell[40100, 971, 474, 10, 22, "Message",ExpressionUUID->"cadeb8cf-7c3e-4039-8d8d-d9d955de0632",
 CellID->2006399642],
Cell[40577, 983, 473, 10, 22, "Message",ExpressionUUID->"7d963dec-5488-4e98-bbbb-4b4f1d850b2e",
 CellID->1770557900],
Cell[41053, 995, 437, 9, 22, "Message",ExpressionUUID->"d7d2cf1f-a07c-4c04-9339-2c8c40d143e5",
 CellID->85728821],
Cell[41493, 1006, 472, 10, 22, "Message",ExpressionUUID->"ac3c5121-608b-45f8-b3c2-580a0bae78ab",
 CellID->1036086511],
Cell[41968, 1018, 473, 10, 22, "Message",ExpressionUUID->"d051d431-e416-4bdc-8c76-d543dd4b2900",
 CellID->1708580501],
Cell[42444, 1030, 474, 10, 22, "Message",ExpressionUUID->"64475ae7-0006-475f-871b-9e4d28a4ffd9",
 CellID->2108636270],
Cell[42921, 1042, 441, 9, 22, "Message",ExpressionUUID->"bef7641f-fc20-4927-ac96-24c37280c821",
 CellID->2074647096],
Cell[43365, 1053, 474, 10, 22, "Message",ExpressionUUID->"bdd543a7-1c90-47d7-ae48-094481414fc6",
 CellID->2049249780],
Cell[43842, 1065, 472, 10, 22, "Message",ExpressionUUID->"f9331a48-ea6b-4d3a-b774-2373aac7a9d5",
 CellID->398321874],
Cell[44317, 1077, 471, 10, 22, "Message",ExpressionUUID->"abdaa819-863b-4267-b6dc-7351f64dcffe",
 CellID->889208619],
Cell[44791, 1089, 438, 9, 22, "Message",ExpressionUUID->"c5b527d7-e7c8-4ede-9f99-c4d160cb882a",
 CellID->590560060],
Cell[45232, 1100, 471, 10, 22, "Message",ExpressionUUID->"5c025b57-5086-4f61-ad6a-2d36ef23533f",
 CellID->1486412803],
Cell[45706, 1112, 471, 10, 22, "Message",ExpressionUUID->"0e38f96b-1184-41dd-b4aa-e51530044c09",
 CellID->462714470],
Cell[46180, 1124, 474, 10, 22, "Message",ExpressionUUID->"48aed172-f8cc-4d63-b8ef-ad306f9a2342",
 CellID->803811503],
Cell[46657, 1136, 439, 9, 22, "Message",ExpressionUUID->"80d67a2a-4556-42f8-be21-f5daf0b70946",
 CellID->1987791291],
Cell[47099, 1147, 472, 10, 22, "Message",ExpressionUUID->"6c11db96-0c5d-4aa1-9f12-9afee64a199e",
 CellID->405131458],
Cell[47574, 1159, 472, 10, 22, "Message",ExpressionUUID->"bb1e202c-70aa-4358-922d-3224145835da",
 CellID->1521253616],
Cell[48049, 1171, 473, 10, 22, "Message",ExpressionUUID->"d54ce087-8302-4d13-98af-dae2c2e097b3",
 CellID->1916706577],
Cell[48525, 1183, 439, 9, 22, "Message",ExpressionUUID->"b210be33-f80d-42c5-baad-796830b46ae5",
 CellID->1832734639],
Cell[48967, 1194, 472, 10, 22, "Message",ExpressionUUID->"3b7672d1-a974-4afd-8e69-04e728efd7c0",
 CellID->1716904035],
Cell[49442, 1206, 471, 10, 22, "Message",ExpressionUUID->"1fdd6535-bd52-4aa4-af96-3bfc06882d2a",
 CellID->268351506],
Cell[49916, 1218, 474, 10, 22, "Message",ExpressionUUID->"b03c118c-ab25-4ea5-8ef1-cde4d83fdc81",
 CellID->468102642],
Cell[50393, 1230, 439, 9, 22, "Message",ExpressionUUID->"abb85d54-6830-4bf7-b9ab-322228308de9",
 CellID->1168505133],
Cell[50835, 1241, 471, 10, 22, "Message",ExpressionUUID->"832cd7fa-7cc5-4a58-86a4-66cd595e38c3",
 CellID->327818516],
Cell[51309, 1253, 473, 10, 22, "Message",ExpressionUUID->"2e70331c-d5b3-4518-b31d-25c03b6c050f",
 CellID->1350243857],
Cell[51785, 1265, 473, 10, 22, "Message",ExpressionUUID->"26c3509b-1473-48ed-8aaf-f855fa256475",
 CellID->1088806750],
Cell[52261, 1277, 438, 9, 22, "Message",ExpressionUUID->"0c21317e-3326-4c9c-9eb2-204e26439781",
 CellID->866891163],
Cell[52702, 1288, 471, 10, 22, "Message",ExpressionUUID->"c5a53b8b-a742-46f6-a2d7-6deb2b18a417",
 CellID->42923341],
Cell[53176, 1300, 475, 10, 22, "Message",ExpressionUUID->"0a597030-8d90-4197-b2a6-d0facb597471",
 CellID->2005570442],
Cell[53654, 1312, 472, 10, 22, "Message",ExpressionUUID->"7dc90549-1595-4f3e-a96f-94eac9ef7c6b",
 CellID->719095382],
Cell[54129, 1324, 439, 9, 22, "Message",ExpressionUUID->"8c5a27c5-8f90-41f5-908a-e80607111410",
 CellID->1945603605],
Cell[54571, 1335, 471, 10, 22, "Message",ExpressionUUID->"ffd31587-85fb-43f0-8f02-63a9349535b9",
 CellID->26296366],
Cell[55045, 1347, 473, 10, 22, "Message",ExpressionUUID->"24b20295-8c3c-4e53-beef-6f43d506b86e",
 CellID->1728875727],
Cell[55521, 1359, 473, 10, 22, "Message",ExpressionUUID->"5df3d9f8-7647-4ebd-9806-8bc225ed0f4a",
 CellID->1760599779],
Cell[55997, 1371, 440, 9, 22, "Message",ExpressionUUID->"7cde7118-c45f-4ecc-aa25-dbfb6c7ca5ae",
 CellID->223313640],
Cell[56440, 1382, 472, 10, 22, "Message",ExpressionUUID->"a95f7b29-a512-4e37-8976-00d64d4238df",
 CellID->958434110],
Cell[56915, 1394, 472, 10, 22, "Message",ExpressionUUID->"e4a3c4c0-e7ad-41f2-b8be-7b050b1e7f0a",
 CellID->127250623],
Cell[57390, 1406, 473, 10, 22, "Message",ExpressionUUID->"16e83bbf-2d21-4468-b660-8928bb590ac4",
 CellID->1954991996],
Cell[57866, 1418, 439, 9, 22, "Message",ExpressionUUID->"ba8a993f-4d22-41a7-be0e-ec1832801aaf",
 CellID->1050677672],
Cell[58308, 1429, 473, 10, 22, "Message",ExpressionUUID->"6b3e79c3-2462-49f3-a816-d88044c7a544",
 CellID->2129087670],
Cell[58784, 1441, 470, 10, 22, "Message",ExpressionUUID->"0b18fa73-b2f3-4bb5-9315-fbefc0e17e9d",
 CellID->56459729],
Cell[59257, 1453, 473, 10, 22, "Message",ExpressionUUID->"97aabbd0-d9ad-4d50-8486-22107796d236",
 CellID->1878376976],
Cell[59733, 1465, 439, 9, 22, "Message",ExpressionUUID->"b0e0de06-f757-4e95-aa36-213c40edc071",
 CellID->1872224732],
Cell[60175, 1476, 472, 10, 22, "Message",ExpressionUUID->"4a4cd1d8-91eb-41e2-82bd-2a3006a9ba14",
 CellID->606404054],
Cell[60650, 1488, 475, 10, 22, "Message",ExpressionUUID->"a0d45052-65bd-45cf-b5be-774f64130c9a",
 CellID->2023030563],
Cell[61128, 1500, 473, 10, 22, "Message",ExpressionUUID->"8f3fac5d-6488-46d1-8229-14e70d07e41f",
 CellID->2113573037],
Cell[61604, 1512, 441, 9, 22, "Message",ExpressionUUID->"d9df0f8b-668a-4843-a6b0-fefe0dc9b224",
 CellID->1295027832],
Cell[62048, 1523, 474, 10, 22, "Message",ExpressionUUID->"97af09fa-77ea-430d-bb95-b4f51e3d1bf0",
 CellID->786010079],
Cell[62525, 1535, 473, 10, 22, "Message",ExpressionUUID->"ec8e02a6-0683-4a7b-a514-9022fe63c43b",
 CellID->1299485056],
Cell[63001, 1547, 472, 10, 22, "Message",ExpressionUUID->"7ce92f86-b714-45fe-a446-271c890421e0",
 CellID->536646202],
Cell[63476, 1559, 439, 9, 22, "Message",ExpressionUUID->"e22bb000-2c92-4c59-829d-5f93c6d5a955",
 CellID->2128883261],
Cell[63918, 1570, 473, 10, 22, "Message",ExpressionUUID->"1a961b1b-73b9-46d0-a35a-b7f0dd757599",
 CellID->1580505039],
Cell[64394, 1582, 475, 10, 22, "Message",ExpressionUUID->"5719a4b4-bbf6-45e1-9d28-b22dfe6fa51e",
 CellID->1322960730],
Cell[64872, 1594, 473, 10, 22, "Message",ExpressionUUID->"b294267f-a9d7-4c57-a336-1fcc2dd5aede",
 CellID->2102791719],
Cell[65348, 1606, 438, 9, 22, "Message",ExpressionUUID->"2a99e7ba-27a8-4330-8ac4-67da3408181b",
 CellID->482042554],
Cell[65789, 1617, 473, 10, 22, "Message",ExpressionUUID->"2a72a437-dc0a-45cd-8312-8dbadaf0c21b",
 CellID->1380888594],
Cell[66265, 1629, 471, 10, 22, "Message",ExpressionUUID->"c3df5abd-d007-42f3-96de-7c5d5a30cd2a",
 CellID->738826229],
Cell[66739, 1641, 472, 10, 22, "Message",ExpressionUUID->"06b75c04-9977-4cec-b422-9f5b4212a672",
 CellID->701983849],
Cell[67214, 1653, 439, 9, 22, "Message",ExpressionUUID->"c5afd020-c210-40d5-8889-8de97403db61",
 CellID->2114877172],
Cell[67656, 1664, 471, 10, 22, "Message",ExpressionUUID->"2f8c8928-f5d0-4548-b8a1-6673774d7601",
 CellID->1642766536],
Cell[68130, 1676, 473, 10, 22, "Message",ExpressionUUID->"de0e5280-08be-4259-9be6-74bc21e8bdd4",
 CellID->1927404720],
Cell[68606, 1688, 473, 10, 22, "Message",ExpressionUUID->"49d2730e-dd68-4a3f-882b-6bb2b4e279f0",
 CellID->1247797692],
Cell[69082, 1700, 441, 9, 22, "Message",ExpressionUUID->"6f49a47a-b9e9-4577-84b2-b42f98074295",
 CellID->1557996489],
Cell[69526, 1711, 472, 10, 22, "Message",ExpressionUUID->"1e42b12c-ec42-4b27-85ac-616f9ad52e14",
 CellID->978882752],
Cell[70001, 1723, 472, 10, 22, "Message",ExpressionUUID->"a21668b5-767e-455c-ad44-0e9c884a89ac",
 CellID->210193197],
Cell[70476, 1735, 472, 10, 22, "Message",ExpressionUUID->"eb3819b3-0156-4e21-b76a-f7654f64a160",
 CellID->106462664],
Cell[70951, 1747, 440, 9, 22, "Message",ExpressionUUID->"0e7caf23-879c-4d67-a166-b893bb8c425b",
 CellID->464115897],
Cell[71394, 1758, 474, 10, 22, "Message",ExpressionUUID->"4adaa144-f0f9-4e89-bcca-186685f09e27",
 CellID->363035951],
Cell[71871, 1770, 470, 10, 22, "Message",ExpressionUUID->"b51d9ea7-1d71-4f8b-bbd7-a453adf34e11",
 CellID->544187330],
Cell[72344, 1782, 471, 10, 22, "Message",ExpressionUUID->"ba49ff56-d37a-4322-8a6a-8681acf387fe",
 CellID->23602737],
Cell[72818, 1794, 439, 9, 22, "Message",ExpressionUUID->"de8cef34-a9e5-4ae6-8178-64b775d783c9",
 CellID->1554209711],
Cell[73260, 1805, 473, 10, 22, "Message",ExpressionUUID->"11c1dac1-53a2-47ed-8b4c-bb4109ca13cc",
 CellID->1759014316],
Cell[73736, 1817, 473, 10, 22, "Message",ExpressionUUID->"eee0e053-4bad-4b6b-8836-ff4b8b6d6f27",
 CellID->1493724410],
Cell[74212, 1829, 474, 10, 22, "Message",ExpressionUUID->"459d6ae8-d57e-478e-993e-d31313b697bb",
 CellID->942325440],
Cell[74689, 1841, 439, 9, 22, "Message",ExpressionUUID->"6d81a68f-0e0c-4a42-8c3d-0853ce40af32",
 CellID->2119257102]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75177, 1856, 91, 0, 181, "ManipulateCaptionSection",ExpressionUUID->"fd663489-3f9b-4207-b2ef-268521a1cfc7"],
Cell[75271, 1858, 88, 0, 23, "ManipulateCaption",ExpressionUUID->"302d07c6-02fe-4684-abc9-0d3700fd6edc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75396, 1863, 83, 0, 179, "ThumbnailSection",ExpressionUUID->"ee8dee11-2f09-4ef6-a43f-53ca5aa2a910"],
Cell[75482, 1865, 1300, 35, 230, "Output",ExpressionUUID->"c6a896c9-2347-442b-a266-14bc166d0ed1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76819, 1905, 83, 0, 149, "SnapshotsSection",ExpressionUUID->"5d2131fa-1858-433d-9fc7-45ce3c963648"],
Cell[76905, 1907, 1299, 35, 230, "Output",ExpressionUUID->"e1f947cf-914e-4f18-8722-5a600df03d40"]
}, Open  ]],
Cell[78219, 1945, 81, 0, 359, "DetailsSection",ExpressionUUID->"c36b1e03-9047-434c-8cd0-f943927aaaee"],
Cell[CellGroupData[{
Cell[78325, 1949, 92, 0, 119, "ControlSuggestionsSection",ExpressionUUID->"274b42bf-5f4d-45c5-ad61-baabfe6f811a"],
Cell[78420, 1951, 432, 11, 29, "ControlSuggestions",ExpressionUUID->"5ceea481-7fa3-4c42-90ee-3ecb119a18c9",
 CellTags->"ResizeImages"],
Cell[78855, 1964, 800, 19, 29, "ControlSuggestions",ExpressionUUID->"c825d213-971a-4bd0-bccd-b83d327c3201",
 CellTags->"RotateAndZoomIn3D"],
Cell[79658, 1985, 460, 14, 29, "ControlSuggestions",ExpressionUUID->"5405a9e7-3801-4a7f-ba0b-c28f417b6bdc",
 CellTags->"DragLocators"],
Cell[80121, 2001, 761, 19, 29, "ControlSuggestions",ExpressionUUID->"b5a5dd3d-691a-4c66-88c5-3076752e3753",
 CellTags->"CreateAndDeleteLocators"],
Cell[80885, 2022, 961, 23, 29, "ControlSuggestions",ExpressionUUID->"cd527a51-b046-4eb1-b18a-3410745efb53",
 CellTags->"SliderZoom"],
Cell[81849, 2047, 491, 12, 29, "ControlSuggestions",ExpressionUUID->"467ba4d2-738e-4d76-8d42-8914b41745d8",
 CellTags->"GamepadControls"],
Cell[82343, 2061, 1586, 34, 29, "ControlSuggestions",ExpressionUUID->"95a87a10-f466-457a-b910-b0f908d1f752",
 CellTags->"AutomaticAnimation"],
Cell[83932, 2097, 1030, 24, 29, "ControlSuggestions",ExpressionUUID->"4e896c0f-2572-4aa7-935a-0faa6694b4a3",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[84977, 2124, 85, 0, 165, "SearchTermsSection",ExpressionUUID->"ff84138c-706a-4897-9a1f-097652198420"],
Cell[85065, 2126, 86, 0, 137, "RelatedLinksSection",ExpressionUUID->"4d828e45-7343-47bc-a9e6-12a143caa27e"],
Cell[CellGroupData[{
Cell[85176, 2130, 80, 0, 137, "AuthorSection",ExpressionUUID->"d745326b-62bb-426b-b9af-5882a77df039"],
Cell[85259, 2132, 93, 0, 23, "Author",ExpressionUUID->"7fa71a4e-7543-4e3d-9e3e-11f052a3c493"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* NotebookSignature mwD2QIs#CXHYnC1w4R4D53vl *)
