(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    134052,       2696]
NotebookOptionsPosition[    121310,       2448]
NotebookOutlinePosition[    127489,       2575]
CellTagsIndexPosition[    126817,       2553]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Marcus Theory of Electron Transfer - 1\nClassical ",
 StyleBox["vs",
  FontSlant->"Italic"],
 " Semi-Classical Electron Transfer Rates"
}], "Title",
 CellChangeTimes->{{3.845184211750225*^9, 3.845184248615171*^9}, {
  3.845185289447962*^9, 3.845185303736915*^9}, {3.845195443634798*^9, 
  3.845195452428026*^9}, {3.845209849258016*^9, 
  3.8452098540480757`*^9}},ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-\
13c361826e91"],

Cell[TextData[{
 "Initialization Code",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Initialization Code", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"Provide any code that must be evaluated before the ", 
          StyleBox["Manipulate", "MRbig"], 
          ". This will automatically be built into the ", 
          StyleBox["Manipulate", "MRbig"], 
          " in the final notebook version. Never use a package that is not \
included in the default distribution of ", 
          StyleBox["Mathematica", FontSlant -> "Italic"], 
          ". To use a package, use the ", 
          StyleBox["Initialization", "MRbig"], " option (with ", 
          StyleBox["Get", "MRbig"], ", not ", 
          StyleBox["Needs", "MRbig"], ") in the ", 
          StyleBox["Manipulate", "MRbig"], 
          " itself, and use the full name of the function from the package. \
For example:\n", 
          StyleBox[
          "  Manipulate[\n  ...\n  ComputationalGeometry`ConvexHull[...]...\n \
 ...\n  Initialization :> Get[\"ComputationalGeometry`\"],\n  ...\n  ]", 
           "MR"], "\nIf you provide initialization code, include a ", 
          StyleBox["SaveDefinitions->True", "MRbig"], " option in the ", 
          StyleBox["Manipulate", "MRbig"], ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "81fde376-e763-44cf-83ed-5c52ec315067"]
}], "InitializationSection",
 CellTags->
  "Initialization \
Code",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f"],

Cell[CellGroupData[{

Cell["", "InitializationSection",
 CellChangeTimes->{3.8452023282511473`*^9},
 CellTags->"Initialization Code",
 CellID->706206693,ExpressionUUID->"03ddbbf7-bcb5-4fa4-a34c-f876c35638af"],

Cell[TextData[{
 "This section clears the kernel to prevent ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " from remembering anything we have not told it this session."
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202590451602*^9, 3.845202597894561*^9}},
 CellID->1815974521,ExpressionUUID->"268f75b2-a74d-4c01-aa50-92771ab30d00"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Off", "[", 
  RowBox[{"Remove", "::", "rmnsm"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Needs", "[", "\"\<Utilities`CleanSlate`\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"CleanSlate", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]}], "Input",
 CellOpen->False,
 CellLabel->"In[3]:=",
 CellID->520052309,ExpressionUUID->"c9f16438-fe41-4fb0-8d54-be07c2e0f5fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  (CleanSlate) Contexts purged: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["  (CleanSlate) Contexts purged: ", {}],
  Editable->False]], "Print",
 CellOpen->False,
 CellChangeTimes->{3.845182433786922*^9, 3.845185327568532*^9, 
  3.8452075613276577`*^9},
 CellLabel->"During evaluation of In[3]:=",
 CellID->1858494850,ExpressionUUID->"ce42dd7a-627d-4b96-845c-c6359b5c43c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  (CleanSlate) Approximate kernel memory recovered: \"\>", 
   "\[InvisibleSpace]", "\<\"6 Kb\"\>"}],
  SequenceForm["  (CleanSlate) Approximate kernel memory recovered: ", "6 Kb"],
  Editable->False]], "Print",
 CellOpen->False,
 CellChangeTimes->{3.845182433786922*^9, 3.845185327568532*^9, 
  3.845207561591242*^9},
 CellLabel->"During evaluation of In[3]:=",
 CellID->573298335,ExpressionUUID->"c64bfad8-a1ac-449b-8632-c95ae523161e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Utilities`CleanSlate`\"\>", 
   ",", "\<\"Notebook$$26$206989`\"\>", ",", "\<\"System`\"\>"}], 
  "}"}]], "Output",
 CellOpen->False,
 CellChangeTimes->{3.845182433829665*^9, 3.8451853277243443`*^9, 
  3.845207562079638*^9},
 CellLabel->"Out[0]=",
 CellID->1813475903,ExpressionUUID->"51f71959-1ee0-4b09-b301-833ed1d5aa89"],

Cell[BoxData["\<\"/Users/williams/Desktop\"\>"], "Output",
 CellOpen->False,
 CellChangeTimes->{3.845182433829665*^9, 3.8451853277243443`*^9, 
  3.845207564182522*^9},
 CellLabel->"Out[1]=",
 CellID->2001583497,ExpressionUUID->"810e2f8b-40af-47e4-88aa-52fe3d29daee"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Manipulate",
 Cell[BoxData[
  TemplateBox[{"Manipulate", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"This section contains the ", 
          StyleBox["Manipulate", "MRbig"], 
          " input cell and its evaluated output cell. Make all control labels \
or labels in the output as descriptive as possible, with only proper nouns \
and proper adjectives capitalized. More description of the controls can be \
provided in the Details section below, if necessary. If you change this ", 
          StyleBox["Manipulate", "MRbig"], 
          " after creating screenshots and/or thumbnails, use ", 
          StyleBox["Update Thumbnail & Snapshots", FontWeight -> "Bold"], 
          " in the toolbar to update any copies in later sections. You can \
control the Flash preview for the Demonstration with the ", 
          StyleBox["AutorunSequencing", "MRbig"], " option. Use ", 
          StyleBox["SaveDefinitions->True", "MRbig"], 
          " if you provided initialization code in the previous section."}], 
        "MoreInfoText"], Background -> GrayLevel[0.95], FrameMargins -> 20, 
       FrameStyle -> GrayLevel[0.9], RoundingRadius -> 5]], "MoreInfoText", 
     Deletable -> True, CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d12d57a6-93e6-4518-8a9c-9df2eb688354"]
}], "ManipulateSection",
 CellTags->
  "Manipulate",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587"],

Cell[TextData[{
 "This section contains the (hidden) ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code and below the output, in interactive form with sliders. "
}], "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202590451602*^9, 3.845202597894561*^9}, {3.8452026888666477`*^9, 
   3.845202758451004*^9}, {3.8452030749292517`*^9, 3.8452030749295053`*^9}},
 CellID->1454630849,ExpressionUUID->"63930c19-23f2-473b-b87e-abb4c1604cf7"],

Cell["\<\
When the vertical line on the right is black, the values are being calculated.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202590451602*^9, 3.845202597894561*^9}, {3.8452026888666477`*^9, 
   3.845202758451004*^9}, {3.845203076652864*^9, 3.84520310263754*^9}, {
   3.845203743365808*^9, 3.845203745331831*^9}},
 CellID->1843366262,ExpressionUUID->"60ca9904-6c48-4dc2-a743-e38f0b18ed2f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Row", "[", 
    RowBox[{"Quiet", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"KetSC", 
        StyleBox["=",
         FontColor->GrayLevel[0]], 
        RowBox[{
         StyleBox["(",
          FontColor->GrayLevel[0]], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
              
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"0.0000861733033", " ", 
                 RowBox[{"(", "LambdaS", ")"}], " ", "T"}], ")"}], "0.5"]}], 
             ")"}]}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Pi]", 
             RowBox[{"3", "/", "2"}]], "*", 
            SuperscriptBox[
             RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
          SuperscriptBox["V", "2"], "*", 
          RowBox[{"(", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", "0"}], "n"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}]}]], 
                  "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}], "^", 
                   "m"}]}], ")"}], "/", 
                RowBox[{"m", "!"}]}], ")"}], "*", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"-", 
                FractionBox[
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"DeltaG", "+", "LambdaS", "+", 
                    RowBox[{"m", "*", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], 
                  "2"], 
                 RowBox[{"4", "*", "0.0000861733033", "*", 
                  RowBox[{"(", "LambdaS", ")"}], " ", "T"}]]}]]}], ")"}]}], 
           ")"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
       "\"\< = \!\(\*StyleBox[\"Semi\",FontSize->16,FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)\>\"", ",", " ", "\"\<\\n\>\"", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"HR", "=", 
          RowBox[{"LambdaI", "/", 
           RowBox[{"(", 
            RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], " ", 
        "\"\<\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"=\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Huang\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rhys\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\>\""}], ",", "  ", "\"\<\\n\>\"", ",", 
       RowBox[{"(", 
        RowBox[{"FCWD", "=", 
         RowBox[{"(", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"m", "=", "0"}], "n"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}]}]], 
                 "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"LambdaI", "/", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ")"}], "^", 
                  "m"}]}], ")"}], "/", 
               RowBox[{"m", "!"}]}], ")"}], "*", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"DeltaG", "+", "LambdaS", "+", 
                   RowBox[{"m", "*", 
                    RowBox[{"(", 
                    RowBox[{"0.000123985", "*", "vib"}], ")"}]}]}], ")"}], 
                 "2"], 
                RowBox[{"4", "*", "0.0000861733033", "*", 
                 RowBox[{"(", "LambdaS", ")"}], " ", "T"}]]}]]}], ")"}]}], 
          ")"}]}], ")"}], ",", " ", 
       "\"\< \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Franck\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Condon\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Weighted\",FontWeight->\"Bold\"]\)\
\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Density\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"of\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"states\",FontWeight->\"Bold\"]\)\>\
\"", ",", "\"\<\\n\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"KoptSC", 
        StyleBox["=",
         FontColor->GrayLevel[0]], 
        RowBox[{
         StyleBox["(",
          FontColor->GrayLevel[0]], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
              
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"0.0000861733033", " ", 
                 RowBox[{"(", "LambdaS", ")"}], " ", "T"}], ")"}], "0.5"]}], 
             ")"}]}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Pi]", 
             RowBox[{"3", "/", "2"}]], "*", 
            SuperscriptBox[
             RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
          SuperscriptBox["V", "2"]}], ")"}]}], ",", " ", 
       "\"\< = \!\(\*StyleBox[\"Pre\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)\>\"", ",", " ", "\"\<\\n\>\"", ",", 
       "\[IndentingNewLine]", " ", "\"\<\\n\>\"", ",", 
       "\"\<_____________________________________________________________\>\"\
", ",", "\"\<\\n\>\"", ",", 
       RowBox[{"(", 
        RowBox[{"KetC", 
         StyleBox["=",
          FontColor->GrayLevel[0]], 
         RowBox[{
          StyleBox["(",
           FontColor->GrayLevel[0]], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"0.0000861733033", " ", 
                  RowBox[{"(", 
                   RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}], 
                 ")"}], "0.5"]}], ")"}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"3", "/", "2"}]], "*", 
             SuperscriptBox[
              RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
           SuperscriptBox["V", "2"], "*", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"DeltaG", "+", "LambdaS", "+", "LambdaI"}], ")"}], 
               "2"], 
              RowBox[{"4", "*", "0.0000861733033", "*", 
               RowBox[{"(", 
                RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}]]}]]}], 
          ")"}]}], ")"}], " ", ",", " ", 
       "\"\< = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)\>\"", ",", "\"\<\\n\>\"", ",", 
       RowBox[{"EAC", "=", 
        RowBox[{"(", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"DeltaG", "+", "LambdaS", "+", "LambdaI"}], ")"}], "2"], 
          RowBox[{"4", "*", 
           RowBox[{"(", 
            RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " "}]], ")"}]}], ",", 
       " ", "\"\< \
\!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Classial\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Activation\",FontSize-\
>16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"energy\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)\>\"", ",", "\"\<\\n\>\"", ",", 
       RowBox[{"(", 
        RowBox[{"KoptC", 
         StyleBox["=",
          FontColor->GrayLevel[0]], 
         RowBox[{
          StyleBox["(",
           FontColor->GrayLevel[0]], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", "4.13566766234016408848168*^-15", ")"}], " ", "*", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"0.0000861733033", " ", 
                  RowBox[{"(", 
                   RowBox[{"LambdaS", "+", "LambdaI"}], ")"}], " ", "T"}], 
                 ")"}], "0.5"]}], ")"}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Pi]", 
              RowBox[{"3", "/", "2"}]], "*", 
             SuperscriptBox[
              RowBox[{"(", "0.000123985", ")"}], "2"]}], " ", ")"}], "*", 
           SuperscriptBox["V", "2"]}], ")"}]}], ")"}], " ", ",", " ", 
       "\"\< = \
\!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Pre\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)\>\"", ",", " ", "\"\<\\n\>\"", ",", 
       "\"\<_____________________________________________________________\>\"\
", ",", "\"\<\\n\>\"", ",", 
       RowBox[{"(", 
        RowBox[{"LambdaT", "=", " ", 
         RowBox[{"LambdaI", " ", "+", "LambdaS"}]}], ")"}], ",", " ", 
       "\"\< = \!\(\*StyleBox[\"Total\",FontSize->16,FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Lambda\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)\>\""}], "}"}], "]"}], " ", "]"}], 
   "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
   "\"\<______________________________________________________________________\
______________\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"DeltaG", ",", 
       RowBox[{"-", "1.537"}], ",", " ", "\"\<Gibbs Free energy (eV)\>\""}], 
      "}"}], ",", "1", ",", 
     RowBox[{"-", "8"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"LambdaS", ",", "0.237", ",", " ", "\"\<Lambda solv (eV)\>\""}],
       "}"}], ",", "0.00001", ",", "8", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"LambdaI", ",", "0.3", ",", " ", "\"\<Lambda Int (eV)\>\""}], 
      "}"}], ",", "0.0001", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", "295", ",", " ", "\"\<T (K)\>\""}], "}"}], ",", "4", 
     ",", "1000", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "vib", ",", "1500", ",", " ", 
       "\"\<vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\""}], "}"}], 
     ",", "4", ",", "10000", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "n", ",", "50", ",", " ", "\"\<Summation factor, n (integer)\>\""}], 
      "}"}], ",", "0", ",", "500", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "V", ",", "6", ",", " ", 
       "\"\<Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))\>\
\""}], "}"}], ",", "0.005", ",", "8066", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   "\"\<______________________________________________________________________\
______________\>\"", ",", "\[IndentingNewLine]", 
   "\"\<______________________________________________________________________\
______________\>\"", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"HR", ",", 
       RowBox[{"LambdaI", "/", 
        RowBox[{"(", 
         RowBox[{"0.000123985", "*", "vib"}], ")"}]}], ",", " ", 
       "\"\<S, Huang Rhys = \>\""}], "}"}], ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Lambdatot", ",", " ", 
       RowBox[{"LambdaI", " ", "+", "LambdaS"}], ",", " ", 
       "\"\<Total Lambda (eV) = \>\""}], "}"}], ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"KbT", ",", " ", 
       RowBox[{"0.0000861733033", " ", "*", "T"}], ",", " ", 
       "\"\<KbT (eV) = \>\""}], "}"}], ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "KetSC", ",", " ", ",", 
       "\"\<Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", \
RowBox[{\"-\", \
\"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\"]\)\
=\>\""}], "}"}], ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.8451825273068953`*^9, {3.8451831548840923`*^9, 3.845183163722225*^9}, {
   3.845183358550314*^9, 3.845183365147552*^9}, {3.8451834038776503`*^9, 
   3.8451834112450666`*^9}, {3.845183480815927*^9, 3.845183513933838*^9}, {
   3.845183632572599*^9, 3.845183649362619*^9}, {3.8451836851551933`*^9, 
   3.845183707845948*^9}, {3.845183806746619*^9, 3.845183815703684*^9}, {
   3.845183931854581*^9, 3.8451840457384243`*^9}, {3.845184106104569*^9, 
   3.845184112269638*^9}, {3.845184747570105*^9, 3.8451847492737513`*^9}, {
   3.8451851943211727`*^9, 3.845185234079588*^9}, {3.8452033500864563`*^9, 
   3.845203426879394*^9}, {3.8452034570924587`*^9, 3.8452034662896223`*^9}, {
   3.845203503569072*^9, 3.8452035084822083`*^9}, {3.84520358120782*^9, 
   3.8452035854698877`*^9}, {3.845203789613493*^9, 3.845203853975953*^9}, {
   3.845203924166236*^9, 3.8452039299603024`*^9}, {3.845204182260497*^9, 
   3.845204184065743*^9}, {3.845204611248558*^9, 3.8452046127500887`*^9}, {
   3.845204703156856*^9, 3.845204713450364*^9}, {3.8452070962416687`*^9, 
   3.845207098197823*^9}, 3.845207255370915*^9, {3.8453508074958057`*^9, 
   3.845350838566491*^9}, {3.84539407458696*^9, 3.84539407536204*^9}, {
   3.845394121013603*^9, 3.8453941472869062`*^9}, {3.845394184703054*^9, 
   3.845394200258546*^9}, {3.845394242072558*^9, 3.8453942471830387`*^9}, {
   3.845395212288435*^9, 3.845395237402588*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
    1.61309835867242, $CellContext`KbT$$ = 
    0.02542112447349969, $CellContext`KetSC$$ = 
    4.669178379156575*^7, $CellContext`LambdaI$$ = 
    0.3, $CellContext`LambdaS$$ = 0.237, $CellContext`Lambdatot$$ = 
    0.3400000000000173, $CellContext`n$$ = 50, $CellContext`T$$ = 
    295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {
    "\"C60-3-TMPD-Tol-CR\"" :> {$CellContext`DeltaG$$ = -1.329, \
$CellContext`HR$$ = 0.7175704442493385, $CellContext`KbT$$ = 
       0.02542112447349969, $CellContext`KetSC$$ = 
       2.947190615672412*^11, $CellContext`LambdaI$$ = 
       0.3000000000000173, $CellContext`LambdaS$$ = 
       0.04, $CellContext`Lambdatot$$ = 0.5369999999999999, $CellContext`n$$ = 
       50, $CellContext`T$$ = 294.9999999999964, $CellContext`vib$$ = 
       3372, $CellContext`V$$ = 100.85}, 
     "\"C60-11-DMA-PhCN-CS\"" :> {$CellContext`DeltaG$$ = -0.47, \
$CellContext`HR$$ = 4.938056200017897, $CellContext`KbT$$ = 
       0.02542112447349969, $CellContext`KetSC$$ = 
       5.55368210388996*^9, $CellContext`LambdaI$$ = 
       0.3000000000000173, $CellContext`LambdaS$$ = 
       0.9, $CellContext`Lambdatot$$ = 0.5369999999999999, $CellContext`n$$ = 
       50, $CellContext`T$$ = 294.9999999999964, $CellContext`vib$$ = 
       490, $CellContext`V$$ = 43}, 
     "\"C60-11-DMA-PhCN-CR\"" :> {$CellContext`DeltaG$$ = -1.29, \
$CellContext`HR$$ = 4.938056200017897, $CellContext`KbT$$ = 
       0.02542112447349969, $CellContext`KetSC$$ = 
       4.212103419415915*^6, $CellContext`LambdaI$$ = 
       0.3000000000000173, $CellContext`LambdaS$$ = 
       0.9, $CellContext`Lambdatot$$ = 0.5369999999999999, $CellContext`n$$ = 
       50, $CellContext`T$$ = 294.9999999999964, $CellContext`vib$$ = 
       490, $CellContext`V$$ = 0.14}, 
     "\"C60[3]TMPD-Tol-CS\"" :> {$CellContext`DeltaG$$ = -0.43, \
$CellContext`HR$$ = 8.961657548180627, $CellContext`KbT$$ = 
       0.02542112447349969, $CellContext`KetSC$$ = 
       3.3348653212440327`*^12, $CellContext`LambdaI$$ = 
       0.3000000000000173, $CellContext`LambdaS$$ = 
       0.04, $CellContext`Lambdatot$$ = 0.5369999999999999, $CellContext`n$$ = 
       50, $CellContext`T$$ = 294.9999999999964, $CellContext`vib$$ = 
       270, $CellContext`V$$ = 97.3}}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled 5\"", Typeset`specs$$ = {{
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`DeltaG$$], -1.537, "Gibbs Free energy (eV)"}, 
      1, -8}, {{
       Hold[$CellContext`LambdaS$$], 0.237, "Lambda solv (eV)"}, 0.00001, 
      8}, {{
       Hold[$CellContext`LambdaI$$], 0.3, "Lambda Int (eV)"}, 0.0001, 2}, {{
       Hold[$CellContext`T$$], 295, "T (K)"}, 4, 1000}, {{
       Hold[$CellContext`vib$$], 1500, 
       "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
       Hold[$CellContext`n$$], 50, "Summation factor, n (integer)"}, 0, 
      500}, {{
       Hold[$CellContext`V$$], 6, 
       "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
      0.005, 8066}, {
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "S, Huang Rhys = "}}, {{
       Hold[$CellContext`Lambdatot$$], $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       "KbT (eV) = "}}, {{
       Hold[$CellContext`KetSC$$], Null, 
       "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\
\", \"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\
\"]\)="}}}, Typeset`size$$ = {462., {215.27593994140625`, 16.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
        Null, $CellContext`LambdaI$$ = 0.3, $CellContext`LambdaS$$ = 
        0.237, $CellContext`Lambdatot$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
        295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[
        Quiet[{$CellContext`KetSC$$ = (((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
               Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
           Sum[((E^(-($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))^$CellContext`m)/
              Factorial[$CellContext`m]) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                  0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
          " = \!\(\*StyleBox[\"Semi\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
          "\n", ($CellContext`HR$$ = $CellContext`LambdaI$$/(
            0.000123985 $CellContext`vib$$)) 
          "\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"=\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Huang\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rhys\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Factor\",FontSize->16,\
FontWeight->\"Bold\"]\)", "\n", $CellContext`FCWD = 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
          " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Franck\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Condon\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Weighted\",FontWeight->\"Bold\"]\)\
\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Density\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"of\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"states\",FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`KoptSC = ((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
              Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
          " = \!\(\*StyleBox[\"Pre\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", "\n", "\n", 
          "_____________________________________________________________", 
          "\n", $CellContext`KetC = (((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
           E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
          " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
          
          "\n", $CellContext`EAC = ($CellContext`DeltaG$$ + \
$CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
           4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
          " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Classial\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Activation\",FontSize-\
>16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"energy\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`KoptC = ((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
          " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Pre\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", "\n", 
          "_____________________________________________________________", 
          "\n", $CellContext`LambdaT = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, 
          " = \!\(\*StyleBox[\"Total\",FontSize->16,FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Lambda\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)"}]], 
      "Specifications" :> {
       "______________________________________________________________________\
______________", {{$CellContext`DeltaG$$, -1.537, "Gibbs Free energy (eV)"}, 
         1, -8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaS$$, 0.237, "Lambda solv (eV)"}, 
         0.00001, 8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaI$$, 0.3, "Lambda Int (eV)"}, 
         0.0001, 2, Appearance -> 
         "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 4, 1000, Appearance -> 
         "Labeled"}, {{$CellContext`vib$$, 1500, 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
         Appearance -> 
         "Labeled"}, {{$CellContext`n$$, 50, "Summation factor, n (integer)"},
          0, 500, Appearance -> 
         "Labeled"}, {{$CellContext`V$$, 6, 
          "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
         0.005, 8066, Appearance -> "Labeled"}, 
        "_____________________________________________________________________\
_______________", 
        "_____________________________________________________________________\
_______________", {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "S, Huang Rhys = "}, Appearance -> 
         "Labeled"}, {{$CellContext`Lambdatot$$, $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}, Appearance -> 
         "Labeled"}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          "KbT (eV) = "}, Appearance -> 
         "Labeled"}, {{$CellContext`KetSC$$, Null, 
          "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\
\"-\", \"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"\
Plain\"]\)="}, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{900., {167., 172.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`FCWD = 
       0.0024319914920172036`, $CellContext`KoptSC = 
       1.9198991421157265`*^10, $CellContext`KetC = 
       141.97783096879084`, $CellContext`EAC = 
       0.4655493482309123, $CellContext`KoptC = 
       1.275455892984475*^10, $CellContext`LambdaT = 0.5369999999999999}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.845183517103009*^9, 3.845183652223049*^9, 3.845183713161881*^9, 
   3.845183822071912*^9, 3.84518385675845*^9, 3.845184012354898*^9, 
   3.8451840480610657`*^9, 3.845184119863558*^9, 3.84518464026937*^9, {
   3.845184752487824*^9, 3.8451847764494667`*^9}, 3.845185033944242*^9, 
   3.845185328757227*^9, 3.845202885081719*^9, 3.8452034732779207`*^9, 
   3.8452035170145493`*^9, 3.845203630223341*^9, 3.845203860214446*^9, 
   3.845203936761176*^9, 3.845204128824177*^9, 3.8452042259207983`*^9, 
   3.84520430993897*^9, 3.845204528817576*^9, 3.845204823008532*^9, 
   3.8452071232996387`*^9, 3.845207268886384*^9, 3.845207569614366*^9, 
   3.8452079972113132`*^9, 3.845208292130579*^9, 3.845294322608531*^9, {
   3.845351453984399*^9, 3.845351459934478*^9}, 3.84539426592684*^9, 
   3.845394983907465*^9, 3.845395163307884*^9, 3.84539526938142*^9, 
   3.845395542842581*^9, {3.845396460488511*^9, 3.845396473447916*^9}},
 CellLabel->"Out[3]=",
 CellID->1787899435,ExpressionUUID->"1a5c8f74-2501-48c4-97f1-fde34903d939"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Input",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.845395371724429*^9},
 CellID->1634615221,ExpressionUUID->"70b879ae-f748-4e15-b7da-40de5e70a90e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Caption",
 Cell[BoxData[
  TemplateBox[{"Caption", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "The caption provides all the information needed to understand the \
Demonstration. It should be between three and five sentences long, but \
clarity is more important than length. Include only text in this section \
\[LongDash] no code, graphics, etc. Do not change the cell style or copy \
cells from other sections. Do not copy text from books or the web. Write your \
ideas in your own words. If you want to refer to something on the web, link \
to it in the Details.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "a97b5d36-1c59-4018-b3f0-6bfc71662d3d"]
}], "ManipulateCaptionSection",
 CellTags->"Caption",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4"],

Cell["\<\
This notebook makes it easy to compare rates predicted by the Marcus theory \
of Electron Transfer, comparing the Classical Marcus model with the \
Semi-Classical Marcus model (also called Marcus-Levich-Jortner Theory). The \
starting values are from the so-called Closs and Miller data, the first \
experimental proof of the inverted region (focussed here on the iso-octane \
data).\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.8453980043057327`*^9, 3.845398004305916*^9}},
 CellID->2005410859,ExpressionUUID->"173b010b-227c-4944-979d-b7418900dd01"],

Cell["\<\
We need to apply the Semi-Classical Marcus expression when we are in the \
Inverted Region. If the Delta G is much larger than the Total Lambda, then \
Inverted Region effects are clear. \
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.845398006879942*^9, 3.845398138772657*^9}},
 CellID->86693020,ExpressionUUID->"6e141691-0beb-4321-ae31-7dae8107c214"],

Cell["\<\
See bookmark of \"C60-3-TMPD-CR\": the total lambda is about 1/4 of the Delta \
G. The rate predicted by the Classical Marcus expression is much too low. \
With the Semi-Classical equation we can get to the measured rate. The other \
bookmarks are for C60[11]DMA in benzonitrile, for charge separation and \
charge recombination. \"Initial setting\" is based on Closs and Miller \
compounds.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, {3.845223840753347*^9, 3.845223883992416*^9}, 
   3.845349775450864*^9, {3.845398006879942*^9, 3.845398275984207*^9}, {
   3.845399056704618*^9, 3.8453991166189203`*^9}, {3.845399160300664*^9, 
   3.845399184860959*^9}},
 CellID->250327041,ExpressionUUID->"7ec4653a-e1c6-4fe2-8535-63cdac4e8d95"],

Cell["\<\
Fit-values bell curve MTHF of CLoss and Miller:
LambdaS = 0.75, LambdaI = 0.45, vib = 1500, V = 6.2, T = 296 K
Epsilon = 6.97, n = 1.406

Fit-values bell curve iso-Octane of Closs and Miller:
LambdaS = 0.15 eV, LambdaI = 0.45, vib = 1500, V = 6.2, T = 296 K
Epsilon = 1.962 n = 1.4029
\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.8451850963655252`*^9, 3.845185096365777*^9}, {
   3.845202811900857*^9, 3.8452028535822563`*^9}, {3.845217912614575*^9, 
   3.84521794565343*^9}, 3.845223840753347*^9, {3.8453982974966497`*^9, 
   3.845398308889051*^9}},
 CellID->1438951199,ExpressionUUID->"0d12da80-68d0-43eb-be6f-f9f862bc5fab"],

Cell["\<\
The \"n\" is in the summation factor, and makes it possible to see how many \
\"transfer channels\" play a role, and how they contribute to the total rate. \
Other aspects are defined in the output interface.\
\>", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9, {3.845184862792486*^9, 3.8451849295195208`*^9}, 
   3.845185011474946*^9, {3.845185102397773*^9, 3.845185168958621*^9}, {
   3.8451854057830257`*^9, 3.8451854276303596`*^9}, {3.845185591268705*^9, 
   3.845185593171544*^9}, {3.845202990498258*^9, 3.8452030136749983`*^9}, 
   3.845204481980147*^9, {3.845207429356279*^9, 3.845207431260901*^9}},
 CellID->518981415,ExpressionUUID->"7d659399-279e-4284-8e8f-42263df8c8ef"],

Cell["", "ManipulateCaption",
 CellChangeTimes->{{3.845184388092617*^9, 3.8451844777746763`*^9}, 
   3.845184523039246*^9},
 CellID->159051497,ExpressionUUID->"be873a41-f7e9-42e0-8496-64b1e3104908"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Thumbnail",
 Cell[BoxData[
  TemplateBox[{"Thumbnail", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "To create the thumbnail, copy and paste the output cell from the ", 
          
          StyleBox["Manipulate", "MRbig"], 
          " section and adjust the controls to the most visually appealing \
setting. Do not convert it to a bitmap. The thumbnail is what visitors see \
when browsing the Demonstrations site and while the Flash preview loads.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "5363174b-397a-4e31-b8e5-95e1af887bc9"]
}], "ThumbnailSection",
 CellTags->"Thumbnail",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = -0.47, $CellContext`HR$$ = 
    4.938056200017612, $CellContext`KbT$$ = 
    0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
    5.55368210389103*^9, $CellContext`LambdaI$$ = 
    0.3, $CellContext`LambdaS$$ = 
    0.9, $CellContext`LT$$ = $CellContext`LambdaI$$ + $CellContext`LambdaS$$, \
$CellContext`n$$ = 50, $CellContext`T$$ = 295, $CellContext`V$$ = 
    43, $CellContext`vib$$ = 490., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"C60-11-DMA-CS1-PhCN\"" :> {$CellContext`DeltaG$$ = -0.47, \
$CellContext`HR$$ = 4.938056200017612, $CellContext`KbT$$ = 
       0.0254211244735, $CellContext`KetSC$$ = 
       5.55368210389103*^9, $CellContext`LambdaI$$ = 
       0.3, $CellContext`LambdaS$$ = 0.9, $CellContext`LT$$ = 
       0.5369999999999999, $CellContext`n$$ = 50, $CellContext`T$$ = 
       295, $CellContext`vib$$ = 490., $CellContext`V$$ = 43}}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled 2\"", Typeset`specs$$ = {{
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`DeltaG$$], -1.537, "Gibbs Free energy (eV)"}, 
      1, -8}, {{
       Hold[$CellContext`LambdaS$$], 0.237, "Lambda solv (eV)"}, 0.00001, 
      8}, {{
       Hold[$CellContext`LambdaI$$], 0.3, "Lambda Int (eV)"}, 0.0001, 2}, {{
       Hold[$CellContext`T$$], 295, "T (K)"}, 4, 1000}, {{
       Hold[$CellContext`vib$$], 1500, 
       "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
       Hold[$CellContext`n$$], 50, "Summation factor, n (integer)"}, 0, 
      500}, {{
       Hold[$CellContext`V$$], 6, 
       "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
      0.005, 8066}, {
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "S, Huang Rhys = "}}, {{
       Hold[$CellContext`LT$$], $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       "KbT (eV) = "}}, {{
       Hold[$CellContext`KetSC$$], Null, 
       "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\
\", \"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\
\"]\)="}}}, Typeset`size$$ = {462., {175.27593994140625`, 16.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
        Null, $CellContext`LambdaI$$ = 0.3, $CellContext`LambdaS$$ = 
        0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
        295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[
        Quiet[{$CellContext`KetSC$$ = (((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
               Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
           Sum[((E^(-($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))^$CellContext`m)/
              Factorial[$CellContext`m]) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                  0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
          " = \!\(\*StyleBox[\"Semi\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
          "\n", ($CellContext`HR$$ = $CellContext`LambdaI$$/(
            0.000123985 $CellContext`vib$$)) 
          "\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"=\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Huang\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rhys\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Factor\",FontSize->16,\
FontWeight->\"Bold\"]\)", "\n", $CellContext`FCWD = 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
          " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Franck\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Condon\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Weighted\",FontWeight->\"Bold\"]\)\
\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Density\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"of\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"states\",FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`KoptSC = ((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
              Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
          " = \!\(\*StyleBox[\"Pre\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", "\n", "\n", 
          "_____________________________________________________________", 
          "\n", $CellContext`KetC = (((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
           E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
          " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`EAC = ($CellContext`DeltaG$$ + \
$CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
           4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
          " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Classial\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Activation\",FontSize-\
>16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"energy\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`KoptC = ((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
          " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Pre\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)"}]], 
      "Specifications" :> {
       "______________________________________________________________________\
______________", {{$CellContext`DeltaG$$, -1.537, "Gibbs Free energy (eV)"}, 
         1, -8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaS$$, 0.237, "Lambda solv (eV)"}, 
         0.00001, 8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaI$$, 0.3, "Lambda Int (eV)"}, 
         0.0001, 2, Appearance -> 
         "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 4, 1000, Appearance -> 
         "Labeled"}, {{$CellContext`vib$$, 1500, 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
         Appearance -> 
         "Labeled"}, {{$CellContext`n$$, 50, "Summation factor, n (integer)"},
          0, 500, Appearance -> 
         "Labeled"}, {{$CellContext`V$$, 6, 
          "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
         0.005, 8066, Appearance -> "Labeled"}, 
        "_____________________________________________________________________\
_______________", 
        "_____________________________________________________________________\
_______________", {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "S, Huang Rhys = "}, Appearance -> 
         "Labeled"}, {{$CellContext`LT$$, $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}, Appearance -> 
         "Labeled"}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          "KbT (eV) = "}, Appearance -> 
         "Labeled"}, {{$CellContext`KetSC$$, Null, 
          "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\
\"-\", \"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"\
Plain\"]\)="}, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{900., {167., 172.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`FCWD = 
       0.0024319914920172036`, $CellContext`KoptSC = 
       1.9198991421157265`*^10, $CellContext`KetC = 
       141.97783096879084`, $CellContext`EAC = 
       0.4655493482309123, $CellContext`KoptC = 1.275455892984475*^10}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.8452077539273148`*^9, 3.8452078423552847`*^9, {3.84535107711239*^9, 
   3.8453510860436296`*^9}},ExpressionUUID->"58c040db-333b-4c73-bea5-\
902ccd2013e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Snapshots",
 Cell[BoxData[
  TemplateBox[{"Snapshots", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{"To create snapshots, paste the output cell from the ", 
          StyleBox["Manipulate", "MRbig"], 
          " section in this section at least three times, and adjust the \
controls of each copy to show a range of interesting settings. Do not convert \
the screenshots to bitmaps. Optional captions for the screenshots may be \
included in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d854de0f-efbb-449a-8b04-a7b3ca5773d5"]
}], "SnapshotsSection",
 CellTags->"Snapshots",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2"],

Cell[BoxData[{
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`DeltaG$$ = 0, $CellContext`HR$$ = 
    1.61309835867242, $CellContext`KbT$$ = 
    0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
    3.756403658688168*^8, $CellContext`LambdaI$$ = 
    0.3, $CellContext`LambdaS$$ = 
    0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
    295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`DeltaG$$], -1.537, "Gibbs Free energy (eV)"}, 
      1, -8}, {{
       Hold[$CellContext`LambdaS$$], 0.237, "Lambda solv (eV)"}, 0.00001, 
      8}, {{
       Hold[$CellContext`LambdaI$$], 0.3, "Lambda Int (eV)"}, 0.0001, 2}, {{
       Hold[$CellContext`T$$], 295, "T (K)"}, 4, 1000}, {{
       Hold[$CellContext`vib$$], 1500, 
       "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
       Hold[$CellContext`n$$], 50, "Summation factor, n (integer)"}, 0, 
      500}, {{
       Hold[$CellContext`V$$], 6, 
       "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
      0.005, 8066}, {
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
      "_______________________________________________________________________\
_____________"], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`HR$$], 
       8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
       "S, Huang Rhys = "}}, {{
       Hold[$CellContext`LT$$], $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}}, {{
       Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
       "KbT (eV) = "}}, {{
       Hold[$CellContext`KetSC$$], Null, 
       "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\
\", \"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\
\"]\)="}}}, Typeset`size$$ = {462., {175.27593994140625`, 16.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
        Null, $CellContext`LambdaI$$ = 0.3, $CellContext`LambdaS$$ = 
        0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
        295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[
        Quiet[{$CellContext`KetSC$$ = (((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
               Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
           Sum[((E^(-($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))^$CellContext`m)/
              Factorial[$CellContext`m]) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                  0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
          " = \!\(\*StyleBox[\"Semi\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
          "\n", ($CellContext`HR$$ = $CellContext`LambdaI$$/(
            0.000123985 $CellContext`vib$$)) 
          "\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"=\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Huang\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rhys\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Factor\",FontSize->16,\
FontWeight->\"Bold\"]\)", "\n", $CellContext`FCWD = 
          Sum[((E^(-($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                0.000123985 $CellContext`vib$$))^$CellContext`m)/
             Factorial[$CellContext`m]) 
            E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                 0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
          " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Franck\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Condon\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Weighted\",FontWeight->\"Bold\"]\)\
\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Density\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"of\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"states\",FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`KoptSC = ((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
              Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
          " = \!\(\*StyleBox[\"Pre\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", "\n", "\n", 
          "_____________________________________________________________", 
          "\n", $CellContext`KetC = (((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
           E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
          " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`EAC = ($CellContext`DeltaG$$ + \
$CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
           4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
          " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Classial\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Activation\",FontSize-\
>16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"energy\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)", 
          "\n", $CellContext`KoptC = ((1/(
             4.1356676623401640884816799999999999999999999`23.61654563206586*^\
-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
          " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Pre\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)"}]], 
      "Specifications" :> {
       "______________________________________________________________________\
______________", {{$CellContext`DeltaG$$, -1.537, "Gibbs Free energy (eV)"}, 
         1, -8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaS$$, 0.237, "Lambda solv (eV)"}, 
         0.00001, 8, Appearance -> 
         "Labeled"}, {{$CellContext`LambdaI$$, 0.3, "Lambda Int (eV)"}, 
         0.0001, 2, Appearance -> 
         "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 4, 1000, Appearance -> 
         "Labeled"}, {{$CellContext`vib$$, 1500, 
          "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
         Appearance -> 
         "Labeled"}, {{$CellContext`n$$, 50, "Summation factor, n (integer)"},
          0, 500, Appearance -> 
         "Labeled"}, {{$CellContext`V$$, 6, 
          "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
         0.005, 8066, Appearance -> "Labeled"}, 
        "_____________________________________________________________________\
_______________", 
        "_____________________________________________________________________\
_______________", {{$CellContext`HR$$, 
          8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
          "S, Huang Rhys = "}, Appearance -> 
         "Labeled"}, {{$CellContext`LT$$, $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}, Appearance -> 
         "Labeled"}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
          "KbT (eV) = "}, Appearance -> 
         "Labeled"}, {{$CellContext`KetSC$$, Null, 
          "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\
\"-\", \"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"\
Plain\"]\)="}, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{900., {167., 172.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`FCWD = 
       0.0024319914920172036`, $CellContext`KoptSC = 
       1.9198991421157265`*^10, $CellContext`KetC = 
       141.97783096879084`, $CellContext`EAC = 
       0.4655493482309123, $CellContext`KoptC = 1.275455892984475*^10}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]], "\[IndentingNewLine]", 
 RowBox[{
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`DeltaG$$ = -0.537, $CellContext`HR$$ = 
     1.61309835867242, $CellContext`KbT$$ = 
     0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
     7.874346791705783*^9, $CellContext`LambdaI$$ = 
     0.3, $CellContext`LambdaS$$ = 
     0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
     295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500, Typeset`show$$ = 
     True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{
       Hold[
       "______________________________________________________________________\
______________"], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`DeltaG$$], -1.537, "Gibbs Free energy (eV)"}, 
       1, -8}, {{
        Hold[$CellContext`LambdaS$$], 0.237, "Lambda solv (eV)"}, 0.00001, 
       8}, {{
        Hold[$CellContext`LambdaI$$], 0.3, "Lambda Int (eV)"}, 0.0001, 2}, {{
        Hold[$CellContext`T$$], 295, "T (K)"}, 4, 1000}, {{
        Hold[$CellContext`vib$$], 1500, 
        "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
        Hold[$CellContext`n$$], 50, "Summation factor, n (integer)"}, 0, 
       500}, {{
        Hold[$CellContext`V$$], 6, 
        "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
       0.005, 8066}, {
       Hold[
       "______________________________________________________________________\
______________"], Manipulate`Dump`ThisIsNotAControl}, {
       Hold[
       "______________________________________________________________________\
______________"], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`HR$$], 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
        "S, Huang Rhys = "}}, {{
        Hold[$CellContext`LT$$], $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}}, {{
        Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
        "KbT (eV) = "}}, {{
        Hold[$CellContext`KetSC$$], Null, 
        "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", \
RowBox[{\"-\", \
\"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\"]\)\
="}}}, Typeset`size$$ = {462., {175.27593994140625`, 16.}}, Typeset`update$$ =
      0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
         8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
         Null, $CellContext`LambdaI$$ = 0.3, $CellContext`LambdaS$$ = 
         0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
         295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500}, 
       "ControllerVariables" :> {}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Row[
         Quiet[{$CellContext`KetSC$$ = (((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
           " = \!\(\*StyleBox[\"Semi\",FontSize->16,FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
           "\n", ($CellContext`HR$$ = $CellContext`LambdaI$$/(
             0.000123985 $CellContext`vib$$)) 
           "\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"=\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Huang\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rhys\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Factor\",FontSize->16,\
FontWeight->\"Bold\"]\)", "\n", $CellContext`FCWD = 
           Sum[((E^(-($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))^$CellContext`m)/
              Factorial[$CellContext`m]) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                  0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
           " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Franck\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Condon\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Weighted\",FontWeight->\"Bold\"]\)\
\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Density\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"of\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"states\",FontWeight->\"Bold\"]\)", 
           "\n", $CellContext`KoptSC = ((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
               Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
           " = \!\(\*StyleBox[\"Pre\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", "\n", "\n", 
           "_____________________________________________________________", 
           "\n", $CellContext`KetC = (((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2) 
            E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                 0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
           " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
           "\n", $CellContext`EAC = ($CellContext`DeltaG$$ + \
$CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
            4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
           " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Classial\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Activation\",FontSize-\
>16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"energy\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)", 
           "\n", $CellContext`KoptC = ((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
           " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Pre\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)"}]], 
       "Specifications" :> {
        "_____________________________________________________________________\
_______________", {{$CellContext`DeltaG$$, -1.537, "Gibbs Free energy (eV)"}, 
          1, -8, Appearance -> 
          "Labeled"}, {{$CellContext`LambdaS$$, 0.237, "Lambda solv (eV)"}, 
          0.00001, 8, Appearance -> 
          "Labeled"}, {{$CellContext`LambdaI$$, 0.3, "Lambda Int (eV)"}, 
          0.0001, 2, Appearance -> 
          "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 4, 1000, Appearance -> 
          "Labeled"}, {{$CellContext`vib$$, 1500, 
           "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
          Appearance -> 
          "Labeled"}, {{$CellContext`n$$, 50, 
           "Summation factor, n (integer)"}, 0, 500, Appearance -> 
          "Labeled"}, {{$CellContext`V$$, 6, 
           "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"},
           0.005, 8066, Appearance -> "Labeled"}, 
         "____________________________________________________________________\
________________", 
         "____________________________________________________________________\
________________", {{$CellContext`HR$$, 
           8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
           "S, Huang Rhys = "}, Appearance -> 
          "Labeled"}, {{$CellContext`LT$$, $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}, Appearance -> 
          "Labeled"}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
           "KbT (eV) = "}, Appearance -> 
          "Labeled"}, {{$CellContext`KetSC$$, Null, 
           "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", \
RowBox[{\"-\", \
\"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\"]\)\
="}, Appearance -> "Labeled"}}, "Options" :> {}, 
       "DefaultOptions" :> {ControllerLinking -> True}],
      ImageSizeCache->{900., {167., 172.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>({$CellContext`FCWD = 
        0.0024319914920172036`, $CellContext`KoptSC = 
        1.9198991421157265`*^10, $CellContext`KetC = 
        141.97783096879084`, $CellContext`EAC = 
        0.4655493482309123, $CellContext`KoptC = 1.275455892984475*^10}; 
      Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]], 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
     1.61309835867242, $CellContext`KbT$$ = 
     0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
     4.669178379156575*^7, $CellContext`LambdaI$$ = 
     0.3, $CellContext`LambdaS$$ = 
     0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
     295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500, Typeset`show$$ = 
     True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{
       Hold[
       "______________________________________________________________________\
______________"], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`DeltaG$$], -1.537, "Gibbs Free energy (eV)"}, 
       1, -8}, {{
        Hold[$CellContext`LambdaS$$], 0.237, "Lambda solv (eV)"}, 0.00001, 
       8}, {{
        Hold[$CellContext`LambdaI$$], 0.3, "Lambda Int (eV)"}, 0.0001, 2}, {{
        Hold[$CellContext`T$$], 295, "T (K)"}, 4, 1000}, {{
        Hold[$CellContext`vib$$], 1500, 
        "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000}, {{
        Hold[$CellContext`n$$], 50, "Summation factor, n (integer)"}, 0, 
       500}, {{
        Hold[$CellContext`V$$], 6, 
        "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 
       0.005, 8066}, {
       Hold[
       "______________________________________________________________________\
______________"], Manipulate`Dump`ThisIsNotAControl}, {
       Hold[
       "______________________________________________________________________\
______________"], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`HR$$], 
        8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
        "S, Huang Rhys = "}}, {{
        Hold[$CellContext`LT$$], $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}}, {{
        Hold[$CellContext`KbT$$], 0.0000861733033 $CellContext`T$$, 
        "KbT (eV) = "}}, {{
        Hold[$CellContext`KetSC$$], Null, 
        "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", \
RowBox[{\"-\", \
\"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\"]\)\
="}}}, Typeset`size$$ = {462., {175.27593994140625`, 16.}}, Typeset`update$$ =
      0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`DeltaG$$ = -1.537, $CellContext`HR$$ = 
         8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), \
$CellContext`KbT$$ = 0.0000861733033 $CellContext`T$$, $CellContext`KetSC$$ = 
         Null, $CellContext`LambdaI$$ = 0.3, $CellContext`LambdaS$$ = 
         0.237, $CellContext`LT$$ = $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, $CellContext`n$$ = 50, $CellContext`T$$ = 
         295, $CellContext`V$$ = 6, $CellContext`vib$$ = 1500}, 
       "ControllerVariables" :> {}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> Row[
         Quiet[{$CellContext`KetSC$$ = (((1/(
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 $CellContext`LambdaS$$) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2) 
            Sum[((E^(-($CellContext`LambdaI$$/(
                   0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))^$CellContext`m)/
               Factorial[$CellContext`m]) 
              E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                   0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
           " = \!\(\*StyleBox[\"Semi\",FontSize->16,FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
Classical\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
           "\n", ($CellContext`HR$$ = $CellContext`LambdaI$$/(
             0.000123985 $CellContext`vib$$)) 
           "\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"=\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Huang\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rhys\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Factor\",FontSize->16,\
FontWeight->\"Bold\"]\)", "\n", $CellContext`FCWD = 
           Sum[((E^(-($CellContext`LambdaI$$/(
                  0.000123985 $CellContext`vib$$))) ($CellContext`LambdaI$$/(
                 0.000123985 $CellContext`vib$$))^$CellContext`m)/
              Factorial[$CellContext`m]) 
             E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`m (0.000123985 $CellContext`vib$$))^2/(((4 
                  0.0000861733033) $CellContext`LambdaS$$) \
$CellContext`T$$))), {$CellContext`m, 0, $CellContext`n$$}], 
           " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Franck\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Condon\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Weighted\",FontWeight->\"Bold\"]\)\
\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Density\",FontWeight->\"Bold\"]\)\!\
\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"of\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"states\",FontWeight->\"Bold\"]\)", 
           "\n", $CellContext`KoptSC = ((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 $CellContext`LambdaS$$) $CellContext`T$$)^0.5)) ((2 
               Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
           " = \!\(\*StyleBox[\"Pre\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"\
exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", "\n", "\n", 
           "_____________________________________________________________", 
           "\n", $CellContext`KetC = (((1/(
               
               4.1356676623401640884816799999999999999999999`23.\
61654563206586*^-15 ((
                  0.0000861733033 ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 
               0.000123985^2)) $CellContext`V$$^2) 
            E^(-(($CellContext`DeltaG$$ + $CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)^2/(((4 
                 0.0000861733033) ($CellContext`LambdaS$$ + \
$CellContext`LambdaI$$)) $CellContext`T$$))), 
           " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Rate\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[SubscriptBox[\"k\", \
\"et\"],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)", 
           "\n", $CellContext`EAC = ($CellContext`DeltaG$$ + \
$CellContext`LambdaS$$ + $CellContext`LambdaI$$)^2/(
            4 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)), 
           " \!\(\*StyleBox[\"=\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Plain\"]\)\!\(\*StyleBox[\"Classial\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Activation\",FontSize-\
>16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"energy\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"eV\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\
\",FontSize->16,FontWeight->\"Bold\"]\)", 
           "\n", $CellContext`KoptC = ((1/(
              4.1356676623401640884816799999999999999999999`23.61654563206586*\
^-15 ((0.0000861733033 ($CellContext`LambdaS$$ + $CellContext`LambdaI$$)) \
$CellContext`T$$)^0.5)) ((2 Pi^(3/2)) 0.000123985^2)) $CellContext`V$$^2, 
           
           " = \!\(\*StyleBox[\"Classical\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Pre\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"-\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\"exponential\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"factor\",FontSize->16,\
FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"(\",FontSize->16,FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[SuperscriptBox[\"s\", RowBox[{\"-\", \
\"1\"}]],FontSize->16,FontWeight->\"Bold\"]\)\!\(\*StyleBox[\")\",FontSize->\
16,FontWeight->\"Bold\"]\)"}]], 
       "Specifications" :> {
        "_____________________________________________________________________\
_______________", {{$CellContext`DeltaG$$, -1.537, "Gibbs Free energy (eV)"}, 
          1, -8, Appearance -> 
          "Labeled"}, {{$CellContext`LambdaS$$, 0.237, "Lambda solv (eV)"}, 
          0.00001, 8, Appearance -> 
          "Labeled"}, {{$CellContext`LambdaI$$, 0.3, "Lambda Int (eV)"}, 
          0.0001, 2, Appearance -> 
          "Labeled"}, {{$CellContext`T$$, 295, "T (K)"}, 4, 1000, Appearance -> 
          "Labeled"}, {{$CellContext`vib$$, 1500, 
           "vibration (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"}, 4, 10000, 
          Appearance -> 
          "Labeled"}, {{$CellContext`n$$, 50, 
           "Summation factor, n (integer)"}, 0, 500, Appearance -> 
          "Labeled"}, {{$CellContext`V$$, 6, 
           "Electronic coupling, V (\!\(\*SuperscriptBox[\(cm\), \(-1\)]\))"},
           0.005, 8066, Appearance -> "Labeled"}, 
         "____________________________________________________________________\
________________", 
         "____________________________________________________________________\
________________", {{$CellContext`HR$$, 
           8065.491793362099 ($CellContext`LambdaI$$/$CellContext`vib$$), 
           "S, Huang Rhys = "}, Appearance -> 
          "Labeled"}, {{$CellContext`LT$$, $CellContext`LambdaI$$ + \
$CellContext`LambdaS$$, "Total Lambda (eV) = "}, Appearance -> 
          "Labeled"}, {{$CellContext`KbT$$, 0.0000861733033 $CellContext`T$$, 
           "KbT (eV) = "}, Appearance -> 
          "Labeled"}, {{$CellContext`KetSC$$, Null, 
           "Semi-Classical rate (\!\(\*StyleBox[SuperscriptBox[\"s\", \
RowBox[{\"-\", \
\"1\"}]],FontWeight->\"Plain\"]\)\!\(\*StyleBox[\")\",FontWeight->\"Plain\"]\)\
="}, Appearance -> "Labeled"}}, "Options" :> {}, 
       "DefaultOptions" :> {ControllerLinking -> True}],
      ImageSizeCache->{900., {167., 172.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>({$CellContext`FCWD = 
        0.0024319914920172036`, $CellContext`KoptSC = 
        1.9198991421157265`*^10, $CellContext`KetC = 
        141.97783096879084`, $CellContext`EAC = 
        0.4655493482309123, $CellContext`KoptC = 1.275455892984475*^10}; 
      Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}]}], "Output",
 CellEditDuplicate->False,
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.845207829188341*^9, 3.845207836786316*^9}, 
   3.8452079626560926`*^9, 3.84520824522552*^9, 3.84520839842295*^9, 
   3.845208502543766*^9, {3.845208566118835*^9, 3.845208573228773*^9}, {
   3.8453513689116096`*^9, 
   3.845351379747817*^9}},ExpressionUUID->"28ce2d21-e862-4a50-b19b-\
1b190171b769"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Details",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Details", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "This optional section is for a more detailed description of the \
Demonstration than the caption, but it should still be as concise as \
possible. This section may also include numbered snapshot captions (e.g., \
Snapshot 1: phrase or sentence without an initial capital and without a \
period, unless more than one sentence is used) and explanations of the ", 
          StyleBox["Manipulate", "MRbig"], 
          " control labels. Define any symbols undefined so far. Include only \
text in this section \[LongDash] no code, graphics, etc. Do not change the \
cell style or copy cells from other sections. \n\nA book reference uses this \
format: \n    L. D. Schmidt, ", 
          StyleBox[
          "The Engineering of Chemical Reactions", FontSlant -> "Italic"], 
          ", New York: Oxford University Press, 1998. \n\nAn article \
reference uses this format: \n    D. Pearson, \"A Polynomial-Time Algorithm \
for the Change-Making Problem,\" ", 
          StyleBox["Operations Research Letters", FontSlant -> "Italic"], 
          ", ", 
          StyleBox["33", FontWeight -> "Bold"], 
          "(3), 2005 pp. 231\[Dash]234."}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b42cafa3-93cc-45b2-9bce-00512b05ae14"]
}], "DetailsSection",
 CellTags->"Details",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa"],

Cell["\<\
More information on the Marcus theory and rates of electron transfer can be \
found here:\
\>", "DetailNotes",
 CellChangeTimes->{{3.845217249461502*^9, 3.84521730070719*^9}},
 CellID->432095696,ExpressionUUID->"c03462e7-58f5-4c42-b77c-4166954be322"],

Cell["\<\
Electron Transfer Reactions in Chemistry: Theory and Experiment (Nobel \
Lecture)\[Dagger]
https://doi.org/10.1002/anie.199311113 

Electron Transfer Assisted by Vibronic Coupling from Multiple Modes, 
https://doi.org/10.1021/acs.jctc.7b00513

Contemporary Issues in Electron Transfer Research
https://doi.org/10.1021/jp9605663\
\>", "DetailNotes",
 CellChangeTimes->{{3.845217249461502*^9, 3.845217299687502*^9}, {
  3.845217438368167*^9, 3.845217472079977*^9}, {3.845217509503911*^9, 
  3.8452175225212593`*^9}},
 CellID->1766845945,ExpressionUUID->"5b5d878b-784f-4756-b678-71a14cc1d525"],

Cell["", "DetailNotes",
 CellChangeTimes->{{3.845217249461502*^9, 3.845217299687502*^9}, {
  3.845217438368167*^9, 3.845217472079977*^9}, {3.845217509503911*^9, 
  3.845217519575719*^9}},
 CellID->1307065311,ExpressionUUID->"1196c319-6cb9-4a1d-a52d-5dbee8609cec"],

Cell["\<\
Introduction to Electron Transfer
https://doi.org/10.13140/RG.2.2.16547.30244\
\>", "DetailNotes",
 CellChangeTimes->{{3.845217249461502*^9, 3.845217299687502*^9}, {
  3.845217438368167*^9, 3.8452174680225363`*^9}, {3.845217503409424*^9, 
  3.8452175169598722`*^9}},
 CellID->1590059146,ExpressionUUID->"ccbd242b-0a35-4bca-98d1-519dcf399c93"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Control Suggestions",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Control Suggestions", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Check the boxes beside items that are appropriate control \
suggestions for this Demonstration. For more information, see the ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          " page.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "f1fe398c-f37e-4aca-9161-633bae63965a"]
}], "ControlSuggestionsSection",
 CellTags->
  "Control Suggestions",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-\
9fec786547ab"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Resize Images",ExpressionUUID->"fcee1195-e255-4dbd-8863-4af840debdbd"]}],
  
  "\"Click inside an image to reveal its orange resize frame.\\nDrag any of \
the orange resize handles to resize the image.\""]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "ResizeImages",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Rotate and Zoom in 3D",ExpressionUUID->
    "df0b52c8-7325-4803-bb1e-958545cedfd1"]}],
  RowBox[{
   "\"Drag a 3D graphic to rotate it. Starting the drag near the center \
tumbles\\nthe graphic; starting near a corner turns it parallel to the plane \
of the screen.\\nHold down \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" (or \"", 
    FrameBox[
    "Cmd", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" on Mac) and drag up and down to zoom.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "RotateAndZoomIn3D",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Drag Locators",ExpressionUUID->"61b2b2a8-69c4-4012-b6da-8923112012e2"]}],
  
  RowBox[{"\"Drag any locator (\"", 
    GraphicsBox[
     LocatorBox[
      Scaled[{0.5, 0.5}]], ImageSize -> 20], 
    "\", etc.) to move it around.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "DragLocators",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Create and Delete Locators",ExpressionUUID->
    "8e06b60e-3149-4a23-ab31-0a8ab2f5ceaf"]}],
  RowBox[{"\"Insert a new locator in the graphic by holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key\\nand clicking where you want it to be. Delete a locator by \
clicking it\\nwhile holding down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" key.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "CreateAndDeleteLocators",ExpressionUUID->"98a81657-e34e-4dab-ac86-\
717d7eff050a"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Slider Zoom",ExpressionUUID->"c8d377e3-56fc-4adc-88e3-cf7642fb3181"]}],
  RowBox[{"\"Hold down the \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" key while moving a slider to make fine adjustments in the slider \
value.\\nHold \"", 
    FrameBox[
    "Ctrl", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" and/or \"", 
    FrameBox[
    "Shift", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], "\" at the same time as \"", 
    FrameBox[
    "Alt", Background -> GrayLevel[0.9], FrameMargins -> 2, FrameStyle -> 
     GrayLevel[0.9]], 
    "\" to make ever finer adjustments.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "SliderZoom",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Gamepad Controls",ExpressionUUID->
    "1fbb5ded-9a1c-4ba0-a087-0d1c0be219ce"]}],
  "\"Control this Demonstration with a gamepad or other\\nhuman interface \
device connected to your computer.\""]], "ControlSuggestions",
 CellChangeTimes->{3.35696210375764*^9, 3.3895522232313623`*^9},
 FontFamily->"Verdana",
 CellTags->
  "GamepadControls",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Automatic Animation",ExpressionUUID->
    "ec8a5240-77b9-42a0-8b9e-365efb47dfeb"]}],
  RowBox[{"\"Animate a slider in this Demonstration by clicking the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJzzTSzJSM1NLMlMTlRwL0osyMhMLlZwyy8CCjEzMjAwcIKwAgOI/R/IhBKc\n\
/4EAyGAG0f+nTZsGwgysIJIRKsWKLAXGIHFmEpUgLADxWUAkI24jZs+eTaEt\n\
IG+wQKRmzJgBlYf5lhEA30OqWA=="], "Graphics", ImageSize -> {9, 9}, ImageMargins -> 
      0, CellBaseline -> Baseline], BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"button\\nnext to the slider, and then clicking the play button that \
appears.\\nAnimate all controls by selecting \"", 
    StyleBox["Autorun", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "AutomaticAnimation",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f"],

Cell[BoxData[
 TooltipBox[
  RowBox[{
   CheckboxBox[False], Cell[
   " Bookmark Animation",ExpressionUUID->
    "5bdb2812-7da3-4bb1-a7fc-436054c40542"]}],
  RowBox[{
   "\"See a prepared animation of this Demonstration by selecting\\n\"", 
    StyleBox["Animate Bookmarks", FontWeight -> "Bold"], "\" from the\"", 
    AdjustmentBox[
     Cell[
      GraphicsData[
      "CompressedBitmap", 
       "eJyNULENwyAQfEySIlMwTVJlCGRFsosokeNtqBmDBagoaZjAI1C8/8GUUUC6\n\
57h7cQ8PvU7Pl17nUav7oj/TPH7V7b2QJAUAXBkKmCPRowxICy64bRvGGNF7\n\
X8CctGoDSN4xhIDGGDhzFXwUh3/ClBKrDQPmnGXtI6u0OOd+tZBVUqy1xSaH\n\
UqiK6pPe4XdEdAz6563tx/gejuORGMxJaz8mdpJn7hc="], "Graphics", 
      ImageSize -> {10, 10}, ImageMargins -> 0, CellBaseline -> Baseline], 
     BoxBaselineShift -> 0.1839080459770115, 
     BoxMargins -> {{0., 0.}, {-0.1839080459770115, 0.1839080459770115}}], 
    "\"menu.\""}]]], "ControlSuggestions",
 FontFamily->"Verdana",
 CellTags->
  "BookmarkAnimation",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Search Terms",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Search Terms", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide words and phrases that people might search for, with each \
one in a separate cell. Categories are added after the Demonstration is \
submitted, so the best things to enter here are terms (including any \
synonyms) that refer to specific parts of the Demonstration. Do not \
capitalize words unless they are proper names or proper adjectives.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "b8b4550c-a7c1-4c5e-acf4-64f68ac8ea51"]
}], "SearchTermsSection",
 CellTags->
  "Search Terms",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b"],

Cell["\<\
charge separation, charge recombination, photo-induced electron transfer, \
Rudolph Marcus, electron transfer theory, Marcus Levich Jortner, Huang Rhys \
factor, electron phonon coupling \
\>", "SearchTerms",
 CellChangeTimes->{{3.845308911649466*^9, 3.845309009243466*^9}, {
  3.845311693888031*^9, 3.845311702266577*^9}},
 CellID->2129058965,ExpressionUUID->"e22bc3a3-b82f-4979-ae66-4d400b457c50"]
}, Open  ]],

Cell[TextData[{
 "Related Links",
 StyleBox[" (optional) ", "SectionGloss"],
 Cell[BoxData[
  TemplateBox[{"Related Links", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "Provide hyperlinks (not just bare URLs) to any relevant wolfram.com \
pages, with the page title as the linked text. Links to ", 
          ButtonBox[
          "NKS | Online", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://www.wolframscience.com/nks"], None}], 
          " should use the section title, not a page number. Links to \
non-Wolfram sites go in the Details section.", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "d5b26c0d-c135-41cd-9d97-dc9003b05c57"]
}], "RelatedLinksSection",
 CellTags->
  "Related Links",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe"],

Cell[CellGroupData[{

Cell[TextData[{
 "Authoring Information",
 Cell[BoxData[
  TemplateBox[{"Authoring Information", 
    Cell[
     BoxData[
      FrameBox[
       Cell[
        TextData[{
         "'Contributed by: John Smith' for single authors; 'Contributed by: \
John Smith, Robert Ford, and Jane Doe' for multiple authors. To credit people \
other than Demonstrations authors, please see the detailed ", 
          ButtonBox[
          "guidelines", 
           BaseStyle -> {"Hyperlink", FontColor -> RGBColor[0.4, 0.45, 0.5]}, 
           ButtonData -> {
             URL["http://demonstrations.wolfram.com/guidelines.php"], None}], 
          ".", 
          StyleBox["\n", FontSize -> 4]}], "MoreInfoText"], Background -> 
       GrayLevel[0.95], FrameMargins -> 20, FrameStyle -> GrayLevel[0.9], 
       RoundingRadius -> 5]], "MoreInfoText", Deletable -> True, 
     CellTags -> {"SectionMoreInfoDefinition"}, 
     CellMargins -> {{66, 66}, {15, 15}}]},
   "MoreInfoOpenerButtonTemplate"]],ExpressionUUID->
  "990970f3-a922-4bea-919a-d6fa2da1f6d5"]
}], "AuthorSection",
 CellTags->
  "Authoring \
Information",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a"],

Cell["Contributed by:", "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, {
   3.8452088512692413`*^9, 3.845208851269621*^9}, {3.845208894891343*^9, 
   3.845208949377267*^9}, {3.845209062119336*^9, 
   3.845209069168407*^9}},ExpressionUUID->"e6a077c9-f528-4852-97e7-\
764f2f3a1895"],

Cell[TextData[StyleBox["Asst. Prof. Dr. Ren\[EAcute] M. Williams\nMolecular \
Photonics Group\nVan 't Hoff Institute for Molecular Science (HIMS)\n\
Universiteit van Amsterdam\nPostbusnummer 94157\n1090 GD Amsterdam\nThe \
Netherlands\n\nphone +31 (0)20 525 5477\nSecr. +31 (0)20 525 6454\n\n\
R.M.williams@uva.nl\n\n\
https://www.uva.nl/en/profile/w/i/r.m.williams/r.m.williams.html\n\n\
https://www.researchgate.net/publication/225188430_Introduction _to _Electron \
_Transfer",
 FontSize->14]], "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, {
   3.8452088512692413`*^9, 3.845208851269621*^9}, {3.845208894891343*^9, 
   3.845208949377267*^9}, {3.845209062119336*^9, 3.8452090635281963`*^9}, {
   3.845209124676134*^9, 3.845209129974144*^9}},
 CellID->1280385381,ExpressionUUID->"63b7b266-9d07-4819-a956-2fb688c9e418"],

Cell[TextData[StyleBox[ButtonBox["",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://www.researchgate.net/publication/225188430_Introduction_to_\
Electron_Transfer"], None},
 ButtonNote->
  "https://www.researchgate.net/publication/225188430_Introduction_to_\
Electron_Transfer"], "DetailNotes",
 FontSize->18]], "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, {
   3.8452088512692413`*^9, 3.845208851269621*^9}, {3.845208894891343*^9, 
   3.8452089145303307`*^9}, 3.845209149865975*^9},
 CellID->1845915675,ExpressionUUID->"c12792e1-d3c6-4826-bd62-50e3666cfba8"],

Cell["", "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}, {
   3.845208852883542*^9, 3.845208866296411*^9}, 3.84520890529221*^9, 
   3.8452091411845922`*^9},
 CellID->753231681,ExpressionUUID->"968a3953-fefc-4520-adf4-f9f858775565"],

Cell["", "Author",
 CellChangeTimes->{
  3.35696210375764*^9, {3.432333043774981*^9, 3.432333045441087*^9}},
 CellID->148763502,ExpressionUUID->"99d374d5-74af-49b5-abfd-2592dfdbcec2"]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"DemonstrationSource",
WindowSize->{1360, 723},
WindowMargins->{{0, Automatic}, {Automatic, 2}},
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.10.2121", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3, "$ApplicationName" -> "Pubs", "$LinkBase" -> "Pubs", 
    "$ApplicationDirectory" -> "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\jayw\\Desktop\\CVSTree\\Pubs\\Documentation\\English\\", 
    "$UseNewPageDialog" -> "False", "$CondensedBlogMenus" -> "True"}, 
  "PresenterSettings" -> {
   "OutlineThumbnails" -> {"1" -> "Thumbnail"}, 
    "OutlinePalette" -> {"Thumbnails" -> {}, "ThumbnailMagnification" -> 0.8},
     "SideNotesPalette" -> {"PaletteNumber" -> 0}}, "BlogsDirectory" -> 
  "\\\\wrisync02.wri.wolfram.com\\backup$\\jayw\\My \
Documents\\jaywstasks\\BlogTools\\Blogs\\", "ChatNotebookID" -> 
  "fef9786d-4748-42a0-a328-5496e837f205", "Originator" -> 
  "chatframework@wolfram.com", "ScreenName" -> "", "ChatCreationDate" -> 
  "DateObject[{2018, 6, 18, 13, 5, 54.5673134}, Instant, Gregorian, -5.]", 
  "CustomWindowTitle" -> "None", "ChatNotebookDate" -> "18 Jun 2018 13:05:54",
   "ChatNotebookWindowTitle" -> "chatframework's Chat - (18 Jun 2018 13:05)", 
  "Participants" -> {"chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "AllParticipants" -> {
   "chatframework@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "Contacts" -> {
   "andre@wolfram.com", "bradym@wolfram.com", "brianv@wolfram.com", 
    "jayw@wolfram.com", "wan4ren2jie2@gmail.com"}, 
  "EmailListData" -> {0, 0, 0, 0, 1}, "ScrollLock" -> False, "Terminated" -> 
  True, "QuestionState" -> "Timeup", 
  "AttachedCells" -> {
   "Initialization Code" -> None, "Manipulate" -> None, "Caption" -> None, 
    "Snapshots" -> CellObject[77073], "Details" -> None, "Related Links" -> 
    None, "Search Terms" -> CellObject[22897], "Control Suggestions" -> None, 
    "Thumbnail" -> None, "Authoring Information" -> None}},
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Demonstration.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"6e0e27cc-49d0-4db1-87f6-92b4af17a0f8"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Authoring Information"->{
  Cell[117817, 2365, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
   CellTags->"Authoring Information"]},
 "AutomaticAnimation"->{
  Cell[112489, 2234, 1564, 33, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
   CellTags->"AutomaticAnimation"]},
 "BookmarkAnimation"->{
  Cell[114056, 2269, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
   CellTags->"BookmarkAnimation"]},
 "Caption"->{
  Cell[43847, 928, 1138, 24, 68, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
   CellTags->"Caption"]},
 "Control Suggestions"->{
  Cell[107554, 2098, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
   CellTags->"Control Suggestions"]},
 "CreateAndDeleteLocators"->{
  Cell[110328, 2176, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
   CellTags->"CreateAndDeleteLocators"]},
 "Details"->{
  Cell[104234, 2019, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
   CellTags->"Details"]},
 "DragLocators"->{
  Cell[109887, 2161, 438, 13, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
   CellTags->"DragLocators"]},
 "GamepadControls"->{
  Cell[112017, 2221, 469, 11, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
   CellTags->"GamepadControls"]},
 "Initialization Code"->{
  Cell[1021, 34, 1833, 39, 68, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
   CellTags->"Initialization Code"],
  Cell[2879, 77, 186, 3, 67, "InitializationSection",ExpressionUUID->"03ddbbf7-bcb5-4fa4-a34c-f876c35638af",
   CellTags->"Initialization Code",
   CellID->706206693]},
 "Manipulate"->{
  Cell[5821, 157, 1524, 30, 68, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
   CellTags->"Manipulate"]},
 "Related Links"->{
  Cell[116601, 2333, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
   CellTags->"Related Links"]},
 "ResizeImages"->{
  Cell[108688, 2128, 410, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
   CellTags->"ResizeImages"]},
 "RotateAndZoomIn3D"->{
  Cell[109101, 2140, 783, 19, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
   CellTags->"RotateAndZoomIn3D"]},
 "Search Terms"->{
  Cell[115101, 2297, 1073, 24, 178, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
   CellTags->"Search Terms"]},
 "SliderZoom"->{
  Cell[111070, 2196, 944, 23, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
   CellTags->"SliderZoom"]},
 "Snapshots"->{
  Cell[64024, 1305, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
   CellTags->"Snapshots"]},
 "Thumbnail"->{
  Cell[49491, 1040, 1016, 23, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
   CellTags->"Thumbnail"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Authoring Information", 123683, 2493},
 {"AutomaticAnimation", 123855, 2496},
 {"BookmarkAnimation", 124028, 2499},
 {"Caption", 124190, 2502},
 {"Control Suggestions", 124358, 2505},
 {"CreateAndDeleteLocators", 124545, 2508},
 {"Details", 124712, 2511},
 {"DragLocators", 124865, 2514},
 {"GamepadControls", 125029, 2517},
 {"Initialization Code", 125200, 2520},
 {"Manipulate", 125534, 2526},
 {"Related Links", 125691, 2529},
 {"ResizeImages", 125855, 2532},
 {"RotateAndZoomIn3D", 126021, 2535},
 {"Search Terms", 126187, 2538},
 {"SliderZoom", 126348, 2541},
 {"Snapshots", 126504, 2544},
 {"Thumbnail", 126657, 2547}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 438, 10, 160, "Title",ExpressionUUID->"b9e6fe14-67c5-4f7d-9ec0-13c361826e91"],
Cell[1021, 34, 1833, 39, 68, "InitializationSection",ExpressionUUID->"1d34a731-8c48-4189-8b6f-89ef5777db9f",
 CellTags->"Initialization Code"],
Cell[CellGroupData[{
Cell[2879, 77, 186, 3, 67, "InitializationSection",ExpressionUUID->"03ddbbf7-bcb5-4fa4-a34c-f876c35638af",
 CellTags->"Initialization Code",
 CellID->706206693],
Cell[3068, 82, 542, 10, 23, "ManipulateCaption",ExpressionUUID->"268f75b2-a74d-4c01-aa50-92771ab30d00",
 CellID->1815974521],
Cell[CellGroupData[{
Cell[3635, 96, 557, 13, 19, "Input",ExpressionUUID->"c9f16438-fe41-4fb0-8d54-be07c2e0f5fb",
 CellOpen->False,
 CellID->520052309],
Cell[4195, 111, 449, 10, 19, "Print",ExpressionUUID->"ce42dd7a-627d-4b96-845c-c6359b5c43c1",
 CellOpen->False,
 CellID->1858494850],
Cell[4647, 123, 486, 10, 19, "Print",ExpressionUUID->"c64bfad8-a1ac-449b-8632-c95ae523161e",
 CellOpen->False,
 CellID->573298335],
Cell[5136, 135, 367, 9, 19, "Output",ExpressionUUID->"51f71959-1ee0-4b09-b301-833ed1d5aa89",
 CellOpen->False,
 CellID->1813475903],
Cell[5506, 146, 266, 5, 19, "Output",ExpressionUUID->"810e2f8b-40af-47e4-88aa-52fe3d29daee",
 CellOpen->False,
 CellID->2001583497]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5821, 157, 1524, 30, 68, "ManipulateSection",ExpressionUUID->"b7acceb9-ca4b-4965-b319-bd8a6214a587",
 CellTags->"Manipulate"],
Cell[7348, 189, 639, 11, 23, "ManipulateCaption",ExpressionUUID->"63930c19-23f2-473b-b87e-abb4c1604cf7",
 CellID->1454630849],
Cell[7990, 202, 604, 9, 23, "ManipulateCaption",ExpressionUUID->"60ca9904-6c48-4dc2-a743-e38f0b18ed2f",
 CellID->1843366262],
Cell[CellGroupData[{
Cell[8619, 215, 18610, 419, 19, "Input",ExpressionUUID->"1c8a51fe-61b3-446f-b3f3-b27c622b6763",
 CellOpen->False],
Cell[27232, 636, 16351, 279, 351, "Output",ExpressionUUID->"1a5c8f74-2501-48c4-97f1-fde34903d939",
 CellID->1787899435]
}, Open  ]],
Cell[43598, 918, 212, 5, 27, "Input",ExpressionUUID->"70b879ae-f748-4e15-b7da-40de5e70a90e",
 CellID->1634615221]
}, Open  ]],
Cell[CellGroupData[{
Cell[43847, 928, 1138, 24, 68, "ManipulateCaptionSection",ExpressionUUID->"3ed78bfd-4459-4d2a-906f-3e9e6aba33a4",
 CellTags->"Caption"],
Cell[44988, 954, 933, 14, 39, "ManipulateCaption",ExpressionUUID->"173b010b-227c-4944-979d-b7418900dd01",
 CellID->2005410859],
Cell[45924, 970, 733, 11, 23, "ManipulateCaption",ExpressionUUID->"6e141691-0beb-4321-ae31-7dae8107c214",
 CellID->86693020],
Cell[46660, 983, 1040, 16, 39, "ManipulateCaption",ExpressionUUID->"7ec4653a-e1c6-4fe2-8535-63cdac4e8d95",
 CellID->250327041],
Cell[47703, 1001, 789, 16, 135, "ManipulateCaption",ExpressionUUID->"0d12da80-68d0-43eb-be6f-f9f862bc5fab",
 CellID->1438951199],
Cell[48495, 1019, 758, 11, 23, "ManipulateCaption",ExpressionUUID->"7d659399-279e-4284-8e8f-42263df8c8ef",
 CellID->518981415],
Cell[49256, 1032, 198, 3, 23, "ManipulateCaption",ExpressionUUID->"be873a41-f7e9-42e0-8496-64b1e3104908",
 CellID->159051497]
}, Open  ]],
Cell[CellGroupData[{
Cell[49491, 1040, 1016, 23, 68, "ThumbnailSection",ExpressionUUID->"401cc3c4-8319-4e19-82e7-df5fcb711a42",
 CellTags->"Thumbnail"],
Cell[50510, 1065, 13477, 235, 351, "Output",ExpressionUUID->"58c040db-333b-4c73-bea5-902ccd2013e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64024, 1305, 1018, 22, 68, "SnapshotsSection",ExpressionUUID->"96bb7a68-4496-4362-86d3-c2a0812907f2",
 CellTags->"Snapshots"],
Cell[65045, 1329, 39152, 685, 1091, "Output",ExpressionUUID->"28ce2d21-e862-4a50-b19b-1b190171b769"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104234, 2019, 1796, 36, 68, "DetailsSection",ExpressionUUID->"b9971572-9357-4ce2-a011-62ff9eede7fa",
 CellTags->"Details"],
Cell[106033, 2057, 260, 5, 23, "DetailNotes",ExpressionUUID->"c03462e7-58f5-4c42-b77c-4166954be322",
 CellID->432095696],
Cell[106296, 2064, 600, 14, 135, "DetailNotes",ExpressionUUID->"5b5d878b-784f-4756-b678-71a14cc1d525",
 CellID->1766845945],
Cell[106899, 2080, 263, 4, 23, "DetailNotes",ExpressionUUID->"1196c319-6cb9-4a1d-a52d-5dbee8609cec",
 CellID->1307065311],
Cell[107165, 2086, 352, 7, 39, "DetailNotes",ExpressionUUID->"ccbd242b-0a35-4bca-98d1-519dcf399c93",
 CellID->1590059146]
}, Open  ]],
Cell[CellGroupData[{
Cell[107554, 2098, 1131, 28, 68, "ControlSuggestionsSection",ExpressionUUID->"af8a4061-fdd4-44d0-82cc-9fec786547ab",
 CellTags->"Control Suggestions"],
Cell[108688, 2128, 410, 10, 29, "ControlSuggestions",ExpressionUUID->"ac542041-3d26-42bf-920d-b54a74785eef",
 CellTags->"ResizeImages"],
Cell[109101, 2140, 783, 19, 29, "ControlSuggestions",ExpressionUUID->"e14e98ed-7514-4081-99ea-c2ffb624df9b",
 CellTags->"RotateAndZoomIn3D"],
Cell[109887, 2161, 438, 13, 29, "ControlSuggestions",ExpressionUUID->"384b79dc-c11a-492d-87e1-2c4b84403891",
 CellTags->"DragLocators"],
Cell[110328, 2176, 739, 18, 29, "ControlSuggestions",ExpressionUUID->"98a81657-e34e-4dab-ac86-717d7eff050a",
 CellTags->"CreateAndDeleteLocators"],
Cell[111070, 2196, 944, 23, 29, "ControlSuggestions",ExpressionUUID->"b84ac2ce-e422-4d4d-953e-073d63c15a9e",
 CellTags->"SliderZoom"],
Cell[112017, 2221, 469, 11, 29, "ControlSuggestions",ExpressionUUID->"b4dbde82-29d9-4853-88cd-e053ae8d181c",
 CellTags->"GamepadControls"],
Cell[112489, 2234, 1564, 33, 29, "ControlSuggestions",ExpressionUUID->"6e84bbe0-7d8e-44ab-aac1-048973c18d4f",
 CellTags->"AutomaticAnimation"],
Cell[114056, 2269, 1008, 23, 29, "ControlSuggestions",ExpressionUUID->"0cf5a50d-6c0e-4089-a29f-941bc4ca8891",
 CellTags->"BookmarkAnimation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115101, 2297, 1073, 24, 178, "SearchTermsSection",ExpressionUUID->"a3a3a6a7-7876-4115-a51a-6d092bee139b",
 CellTags->"Search Terms"],
Cell[116177, 2323, 409, 7, 23, "SearchTerms",ExpressionUUID->"e22bc3a3-b82f-4979-ae66-4d400b457c50",
 CellID->2129058965]
}, Open  ]],
Cell[116601, 2333, 1191, 28, 68, "RelatedLinksSection",ExpressionUUID->"83b0243b-b7e3-4afb-8a4e-185fec8161fe",
 CellTags->"Related Links"],
Cell[CellGroupData[{
Cell[117817, 2365, 1158, 28, 68, "AuthorSection",ExpressionUUID->"c2736cdb-c24c-4dd4-9a22-5bbef1a7a20a",
 CellTags->"Authoring Information"],
Cell[118978, 2395, 332, 6, 23, "Author",ExpressionUUID->"e6a077c9-f528-4852-97e7-764f2f3a1895"],
Cell[119313, 2403, 873, 14, 311, "Author",ExpressionUUID->"63b7b266-9d07-4819-a956-2fb688c9e418",
 CellID->1280385381],
Cell[120189, 2419, 622, 13, 23, "Author",ExpressionUUID->"c12792e1-d3c6-4826-bd62-50e3666cfba8",
 CellID->1845915675],
Cell[120814, 2434, 282, 5, 23, "Author",ExpressionUUID->"968a3953-fefc-4520-adf4-f9f858775565",
 CellID->753231681],
Cell[121099, 2441, 183, 3, 23, "Author",ExpressionUUID->"99d374d5-74af-49b5-abfd-2592dfdbcec2",
 CellID->148763502]
}, Open  ]]
}, Open  ]]
}
]
*)

